@@ -1,21 +1,16 @@
 /*
-  mkvmerge -- utility for splicing together matroska files
-      from component media subtypes
+   mkvmerge -- utility for splicing together matroska files
+   from component media subtypes
 
-  ac3_common.h
+   Distributed under the GPL
+   see the file COPYING for details
+   or visit http://www.gnu.org/copyleft/gpl.html
 
-  Written by Moritz Bunkus <moritz@bunkus.org>
+   $Id: ac3_common.h 3503 2007-03-02 11:17:25Z mosu $
 
-  Distributed under the GPL
-  see the file COPYING for details
-  or visit http://www.gnu.org/copyleft/gpl.html
-*/
+   definitions and helper functions for AC3 data
 
-/*!
-    \file
-    \version $Id: ac3_common.h 1392 2004-01-10 18:11:06Z mosu $
-    \brief definitions and helper functions for AC3 data
-    \author Moritz Bunkus <moritz@bunkus.org>
+   Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
 #ifndef __AC3COMMON_H
@@ -45,9 +40,12 @@ typedef struct {
   int flags;
   int bytes;
   int bsid;
+  int samples;
 } ac3_header_t;
 
-int MTX_DLL_API find_ac3_header(unsigned char *buf, int size,
+int MTX_DLL_API find_ac3_header(const unsigned char *buf, int size,
                                 ac3_header_t *ac3_header);
+int MTX_DLL_API find_consecutive_ac3_headers(const unsigned char *buf,
+                                             int size, int num);
 
 #endif // __AC3COMMON_H
