@@ -7,7 +7,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: common.cpp 3755 2008-02-26 19:08:38Z mosu $
+   $Id: common.cpp 3838 2008-08-21 15:04:24Z mosu $
 
    helper functions, common variables
 
@@ -204,9 +204,6 @@ die(const char *fmt,
   vfprintf(stdout, fmt, ap);
   va_end(ap);
   mxprint(stdout, "\n");
-#ifdef DEBUG
-  debug_facility.dump_info();
-#endif
   exit(2);
 }
 
@@ -812,14 +809,30 @@ join(const char *pattern,
   return dst;
 }
 
+void
+strip_back(string &s,
+           bool newlines) {
+  const char *c = s.c_str();
+  int len       = s.length();
+  int i         = 0;
+
+  if (newlines)
+    while ((i < len) && (isblanktab(c[len - i - 1]) || iscr(c[len - i - 1])))
+      ++i;
+  else
+    while ((i < len) && isblanktab(c[len - i - 1]))
+      ++i;
+
+  if (i > 0)
+    s.erase(len - i, i);
+}
+
 void
 strip(string &s,
       bool newlines) {
-  int i, len;
-  const char *c;
+  const char *c = s.c_str();
+  int i         = 0;
 
-  c = s.c_str();
-  i = 0;
   if (newlines)
     while ((c[i] != 0) && (isblanktab(c[i]) || iscr(c[i])))
       i++;
@@ -830,19 +843,7 @@ strip(string &s,
   if (i > 0)
     s.erase(0, i);
 
-  c = s.c_str();
-  len = s.length();
-  i = 0;
-
-  if (newlines)
-    while ((i < len) && (isblanktab(c[len - i - 1]) || iscr(c[len - i - 1])))
-      i++;
-  else
-    while ((i < len) && isblanktab(c[len - i - 1]))
-      i++;
-
-  if (i > 0)
-    s.erase(len - i, i);
+  strip_back(s, newlines);
 }
 
 void
@@ -1018,6 +1019,18 @@ downcase(const string &s) {
   return dst;
 }
 
+string
+get_displayable_string(const char *src,
+                       int max_len) {
+  string result;
+  int    len = (-1 == max_len) ? strlen(src) : max_len;
+
+  for (int i = 0; i < len; ++i)
+    result += (' ' > src[i]) ? '?' : src[i];
+
+  return result;
+}
+
 /*
    Integer parsing
 */
@@ -1124,132 +1137,6 @@ to_string(int64_t i) {
   return string(buf);
 }
 
-#ifdef DEBUG
-/*
-   debugging stuff
-*/
-
-debug_c debug_facility;
-
-debug_c::debug_c() {
-}
-
-debug_c::~debug_c() {
-  while (entries.size() > 0) {
-    safefree(entries[entries.size() - 1]);
-    entries.pop_back();
-  }
-}
-
-void
-debug_c::enter(const char *label) {
-  int i;
-  debug_data_t *entry;
-#if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
-  struct timeval tv;
-#endif
-
-  entry = NULL;
-  for (i = 0; i < entries.size(); i++)
-    if (!strcmp(entries[i]->label, label)) {
-      entry = entries[i];
-      break;
-    }
-
-  if (entry == NULL) {
-    entry = (debug_data_t *)safemalloc(sizeof(debug_data_t));
-    memset(entry, 0, sizeof(debug_data_t));
-    entry->label = label;
-    entries.push_back(entry);
-  }
-
-
-#if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
-  gettimeofday(&tv, NULL);
-  entry->entered_at = (uint64_t)tv.tv_sec * (uint64_t)1000000 +
-    tv.tv_usec;
-#else
-  entry->entered_at = (uint64_t)time(NULL) * (uint64_t)1000000;
-#endif
-}
-
-void
-debug_c::leave(const char *label) {
-  int i;
-  debug_data_t *entry;
-#if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
-  struct timeval tv;
-
-  gettimeofday(&tv, NULL);
-#else
-  time_t now;
-
-  now = time(NULL);
-#endif
-
-  entry = NULL;
-  for (i = 0; i < entries.size(); i++)
-    if (!strcmp(entries[i]->label, label)) {
-      entry = entries[i];
-      break;
-    }
-
-  if ((entry == NULL) || (entry->entered_at == 0))
-    die("common.cpp/debug_c::leave() leave without enter: %s", label);
-
-  entry->number_of_calls++;
-#if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
-  entry->elapsed_time += (uint64_t)tv.tv_sec * (uint64_t)1000000 +
-    tv.tv_usec - entry->entered_at;
-#else
-  entry->elapsed_time += (uint64_t)now * (uint64_t)1000000;
-#endif
-  entry->entered_at = 0;
-}
-
-void
-debug_c::add_packetizer(void *ptzr) {
-  int i;
-
-  for (i = 0; i < packetizers.size(); i++)
-    if (packetizers[i] == ptzr)
-      return;
-
-  packetizers.push_back((generic_packetizer_c *)ptzr);
-}
-
-void
-debug_c::dump_info() {
-#if defined(SYS_UNIX) || defined(SYS_APPLE)
-  int i;
-  debug_data_t *entry;
-  uint64_t diff_calls, diff_time;
-
-  mxprint(stdout, "\nDBG> dumping time info:\n");
-  for (i = 0; i < entries.size(); i++) {
-    entry = entries[i];
-    mxprint(stdout, "DBG> function: %s, # calls: " LLU ", elapsed time: %.3fs,"
-            " time/call: %.3fms", entry->label, entry->number_of_calls,
-            entry->elapsed_time / 1000000.0,
-            entry->elapsed_time / (float)entry->number_of_calls / 1000.0);
-    diff_calls = entry->number_of_calls - entry->last_number_of_calls;
-    diff_time = entry->elapsed_time - entry->last_elapsed_time;
-    if ((entry->last_elapsed_time != 0) &&
-        (entry->last_number_of_calls != 0) &&
-        (diff_calls > 0)) {
-      mxprint(stdout, ", since the last call: # calls: " LLU ", elapsed time: "
-              "%.3fs, time/call: %.3fms", diff_calls, diff_time / 1000000.0,
-              diff_time / (float)diff_calls / 1000.0);
-    }
-    mxprint(stdout, "\n");
-    entry->last_elapsed_time = entry->elapsed_time;
-    entry->last_number_of_calls = entry->number_of_calls;
-  }
-#endif // defined SYS_UNIX
-}
-
-#endif // DEBUG
-
 /*
    Other related news
 */
