@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: common.h 3777 2008-03-04 07:35:53Z mosu $
+   $Id: common.h 3876 2008-09-07 12:49:59Z mosu $
 
    definitions used in all programs, helper functions
 
@@ -56,7 +56,7 @@ namespace libebml {
 
 using namespace libebml;
 
-#define VERSIONNAME "Turn It On Again"
+#define VERSIONNAME "Freak U"
 #define VERSIONINFO "mkvmerge v" VERSION " ('" VERSIONNAME "')"
 #define BUGMSG _("This should not have happened. Please contact the author " \
                  "Moritz Bunkus <moritz@bunkus.org> with this error/warning " \
@@ -241,6 +241,7 @@ split(const string &src,
 string MTX_DLL_API join(const char *pattern, const vector<string> &strings);
 void MTX_DLL_API strip(string &s, bool newlines = false);
 void MTX_DLL_API strip(vector<string> &v, bool newlines = false);
+void MTX_DLL_API strip_back(string &s, bool newlines = false);
 string &MTX_DLL_API shrink_whitespace(string &s);
 string MTX_DLL_API escape(const string &src);
 string MTX_DLL_API unescape(const string &src);
@@ -248,6 +249,8 @@ string MTX_DLL_API escape_xml(const string &src);
 string MTX_DLL_API create_xml_node_name(const char *name, const char **atts);
 bool MTX_DLL_API starts_with(const string &s, const char *start,
                              int maxlen = -1);
+string MTX_DLL_API get_displayable_string(const char *src, int max_len = -1);
+
 inline bool
 starts_with(const string &s,
             const string &start,
@@ -324,42 +327,4 @@ public:
   unsigned char *data() const;
 };
 
-#ifdef DEBUG
-
-class generic_packetizer_c;
-
-typedef struct {
-  uint64_t entered_at, elapsed_time, number_of_calls;
-  uint64_t last_elapsed_time, last_number_of_calls;
-
-  const char *label;
-} debug_data_t;
-
-class MTX_DLL_API debug_c {
-private:
-  vector<generic_packetizer_c *> packetizers;
-  vector<debug_data_t *> entries;
-
-public:
-  debug_c();
-  ~debug_c();
-
-  void enter(const char *label);
-  void leave(const char *label);
-  void add_packetizer(void *ptzr);
-  void dump_info();
-};
-
-extern debug_c MTX_DLL_API debug_facility;
-
-#define debug_enter(func) debug_facility.enter(func)
-#define debug_leave(func) debug_facility.leave(func)
-
-#else // DEBUG
-
-#define debug_enter(func)
-#define debug_leave(func)
-
-#endif // DEBUG
-
 #endif // __COMMON_H
