@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: compression.cpp 2859 2005-03-19 11:03:12Z mosu $
+   $Id: compression.cpp 3802 2008-05-16 12:06:21Z mosu $
 
    Helper routines for various compression libs
 
@@ -20,15 +20,33 @@
 
 #include "commonebml.h"
 #include "compression.h"
+#include "hacks.h"
 
 using namespace libmatroska;
 
 const char *compression_methods[] = {
-  "unspecified", "zlib", "bz2", "lzo", "none"
+  "unspecified", "zlib", "bz2", "lzo", "header_removal", "mpeg4_p2", "none"
 };
 
-#if defined(HAVE_LZO1X_H)
-#include <lzoutil.h>
+static const int compression_method_map[] = {
+  0,                            // unspecified
+  0,                            // zlib
+  1,                            // bzlib
+  2,                            // lzo1x
+  3,                            // header removal
+  3,                            // mpeg4_p2 is header removal
+  0                             // none
+};
+
+// ---------------------------------------------------------------------
+
+#ifdef HAVE_LZO
+
+#ifdef HAVE_LZO_LZO1X_H
+# include <lzo/lzoutil.h>
+#else
+# include <lzoutil.h>
+#endif
 
 lzo_compressor_c::lzo_compressor_c():
   compressor_c(COMPRESSION_LZO) {
@@ -45,25 +63,22 @@ lzo_compressor_c::~lzo_compressor_c() {
   safefree(wrkmem);
 }
 
-unsigned char *
-lzo_compressor_c::decompress(unsigned char *buffer,
-                             int &size) {
+void
+lzo_compressor_c::decompress(memory_cptr &buffer) {
   die("lzo_compressor_c::decompress() not implemented\n");
-
-  return NULL;
 }
 
-unsigned char *
-lzo_compressor_c::compress(unsigned char *buffer,
-                           int &size) {
+void
+lzo_compressor_c::compress(memory_cptr &buffer) {
   unsigned char *dst;
-  int result, dstsize;
+  int result, dstsize, size;
 
+  size = buffer->get_size();
   dst = (unsigned char *)safemalloc(size * 2);
 
   lzo_uint lzo_dstsize = size * 2;
-  if ((result = lzo1x_999_compress(buffer, size, dst, &lzo_dstsize,
-                                   wrkmem)) != LZO_E_OK)
+  if ((result = lzo1x_999_compress(buffer->get(), buffer->get_size(),
+                                   dst, &lzo_dstsize, wrkmem)) != LZO_E_OK)
     mxerror("LZO compression failed. Result: %d\n", result);
   dstsize = lzo_dstsize;
 
@@ -75,12 +90,12 @@ lzo_compressor_c::compress(unsigned char *buffer,
   items++;
 
   dst = (unsigned char *)saferealloc(dst, dstsize);
-  size = dstsize;
-
-  return dst;
+  buffer = memory_cptr(new memory_c(dst, dstsize, true));
 }
 
-#endif // HAVE_LZO1X_H
+#endif // HAVE_LZO
+
+// ---------------------------------------------------------------------
 
 #if defined(HAVE_ZLIB_H)
 zlib_compressor_c::zlib_compressor_c():
@@ -90,9 +105,8 @@ zlib_compressor_c::zlib_compressor_c():
 zlib_compressor_c::~zlib_compressor_c() {
 }
 
-unsigned char *
-zlib_compressor_c::decompress(unsigned char *buffer,
-                              int &size) {
+void
+zlib_compressor_c::decompress(memory_cptr &buffer) {
   int result, dstsize, n;
   unsigned char *dst;
   z_stream d_stream;
@@ -104,8 +118,8 @@ zlib_compressor_c::decompress(unsigned char *buffer,
   if (result != Z_OK)
     mxerror("inflateInit() failed. Result: %d\n", result);
 
-  d_stream.next_in = (Bytef *)buffer;
-  d_stream.avail_in = size;
+  d_stream.next_in = (Bytef *)buffer->get();
+  d_stream.avail_in = buffer->get_size();
   n = 0;
   dst = NULL;
   do {
@@ -123,17 +137,14 @@ zlib_compressor_c::decompress(unsigned char *buffer,
   inflateEnd(&d_stream);
 
   mxverb(3, "zlib_compressor_c: Decompression from %d to %d, %d%%\n",
-         size, dstsize, dstsize * 100 / size);
+         buffer->get_size(), dstsize, dstsize * 100 / buffer->get_size());
 
   dst = (unsigned char *)saferealloc(dst, dstsize);
-  size = dstsize;
-
-  return dst;
+  buffer = memory_cptr(new memory_c(dst, dstsize, true));
 }
 
-unsigned char *
-zlib_compressor_c::compress(unsigned char *buffer,
-                            int &size) {
+void
+zlib_compressor_c::compress(memory_cptr &buffer) {
   int result, dstsize, n;
   unsigned char *dst;
   z_stream c_stream;
@@ -145,8 +156,8 @@ zlib_compressor_c::compress(unsigned char *buffer,
   if (result != Z_OK)
     mxerror("deflateInit() failed. Result: %d\n", result);
 
-  c_stream.next_in = (Bytef *)buffer;
-  c_stream.avail_in = size;
+  c_stream.next_in = (Bytef *)buffer->get();
+  c_stream.avail_in = buffer->get_size();
   n = 0;
   dst = NULL;
   do {
@@ -162,16 +173,16 @@ zlib_compressor_c::compress(unsigned char *buffer,
   deflateEnd(&c_stream);
 
   mxverb(3, "zlib_compressor_c: Compression from %d to %d, %d%%\n",
-         size, dstsize, dstsize * 100 / size);
+         buffer->get_size(), dstsize, dstsize * 100 / buffer->get_size());
 
   dst = (unsigned char *)saferealloc(dst, dstsize);
-  size = dstsize;
-
-  return dst;
+  buffer = memory_cptr(new memory_c(dst, dstsize, true));
 }
 
 #endif // HAVE_ZLIB_H
 
+// ---------------------------------------------------------------------
+
 #if defined(HAVE_BZLIB_H)
 bzlib_compressor_c::bzlib_compressor_c():
   compressor_c(COMPRESSION_BZ2) {
@@ -180,9 +191,8 @@ bzlib_compressor_c::bzlib_compressor_c():
 bzlib_compressor_c::~bzlib_compressor_c() {
 }
 
-unsigned char *
-bzlib_compressor_c::decompress(unsigned char *buffer,
-                               int &size) {
+void
+bzlib_compressor_c::decompress(memory_cptr &buffer) {
   int result;
   bz_stream d_stream;
 
@@ -196,17 +206,15 @@ bzlib_compressor_c::decompress(unsigned char *buffer,
   if (result != BZ_OK)
     mxerror("BZ2_bzCompressInit() failed. Result: %d\n", result);
   BZ2_bzDecompressEnd(&d_stream);
-
-  return NULL;
 }
 
-unsigned char *
-bzlib_compressor_c::compress(unsigned char *buffer,
-                             int &size) {
+void
+bzlib_compressor_c::compress(memory_cptr &buffer) {
   unsigned char *dst;
-  int result, dstsize;
+  int result, dstsize, size;
   bz_stream c_stream;
 
+  size = buffer->get_size();
   dst = (unsigned char *)safemalloc(size * 2);
 
   c_stream.bzalloc = NULL;
@@ -217,14 +225,16 @@ bzlib_compressor_c::compress(unsigned char *buffer,
   if (result != BZ_OK)
     mxerror("BZ2_bzCompressInit() failed. Result: %d\n", result);
 
-  c_stream.next_in = (char *)buffer;
+  c_stream.next_in = (char *)buffer->get();
   c_stream.next_out = (char *)dst;
   c_stream.avail_in = size;
   c_stream.avail_out = 2 * size;
-  result = BZ2_bzCompress(&c_stream, BZ_FLUSH);
-  if (result != BZ_RUN_OK)
+  result = BZ2_bzCompress(&c_stream, BZ_FINISH);
+  if (result != BZ_STREAM_END)
     mxerror("bzip2 compression failed. Result: %d\n", result);
 
+  BZ2_bzCompressEnd(&c_stream);
+
   dstsize = 2 * size - c_stream.avail_out;
 
   mxverb(3, "bzlib_compressor_c: Compression from %d to %d, %d%%\n",
@@ -235,23 +245,112 @@ bzlib_compressor_c::compress(unsigned char *buffer,
   items++;
 
   dst = (unsigned char *)saferealloc(dst, dstsize);
-  size = dstsize;
-
-  BZ2_bzCompressEnd(&c_stream);
-
-  return dst;
+  buffer = memory_cptr(new memory_c(dst, dstsize, true));
 }
 
 #endif // HAVE_BZLIB_H
 
+// ---------------------------------------------------------------------
+
+header_removal_compressor_c::header_removal_compressor_c():
+  compressor_c(COMPRESSION_HEADER_REMOVAL) {
+}
+
+void
+header_removal_compressor_c::decompress(memory_cptr &buffer) {
+  if ((NULL == m_bytes.get()) || (0 == m_bytes->get_size()))
+    return;
+
+  memory_cptr new_buffer(new memory_c((unsigned char *)
+                                      safemalloc(buffer->get_size() +
+                                                 m_bytes->get_size()),
+                                      buffer->get_size() + m_bytes->get_size(),
+                                      true));
+  memcpy(new_buffer->get(), m_bytes->get(), m_bytes->get_size());
+  memcpy(new_buffer->get() + m_bytes->get_size(), buffer->get(),
+         buffer->get_size());
+
+  buffer = new_buffer;
+}
+
+void
+header_removal_compressor_c::compress(memory_cptr &buffer) {
+  if ((NULL == m_bytes.get()) || (0 == m_bytes->get_size()))
+    return;
+
+  if (buffer->get_size() < m_bytes->get_size())
+    throw compression_error_c(mxsprintf("Header removal compression not "
+                                        "possible because "
+                                        "the buffer contained %d bytes which "
+                                        "is less than the size of the headers "
+                                        "that should be removed, %d.",
+                                        buffer->get_size(),
+                                        m_bytes->get_size()));
+
+  if (memcmp(buffer->get(), m_bytes->get(), m_bytes->get_size())) {
+    string b_buffer, b_bytes;
+    int i;
+
+    for (i = 0; m_bytes->get_size() > i; ++i) {
+      b_buffer += mxsprintf(" %02x", buffer->get()[i]);
+      b_bytes += mxsprintf(" %02x", m_bytes->get()[i]);
+    }
+    throw compression_error_c(mxsprintf("Header removal compression not "
+                                        "possible because the buffer did not "
+                                        "start with the bytes that should be "
+                                        "removed. Wanted bytes:%s; found:%s.",
+                                        b_bytes.c_str(), b_buffer.c_str()));
+  }
+
+  memmove(buffer->get(), buffer->get() + m_bytes->get_size(),
+          buffer->get_size() - m_bytes->get_size());
+  buffer->set_size(buffer->get_size() - m_bytes->get_size());
+}
+
+void
+header_removal_compressor_c::set_track_headers(KaxContentEncoding
+                                               &c_encoding) {
+  KaxContentCompression *c_comp;
+
+  compressor_c::set_track_headers(c_encoding);
+
+  c_comp = &GetChild<KaxContentCompression>(c_encoding);
+  // Set compression parameters.
+  static_cast<EbmlBinary *>(&GetChild<KaxContentCompSettings>(*c_comp))->
+    SetBuffer(m_bytes->get(), m_bytes->get_size());
+}
+
+mpeg4_p2_compressor_c::mpeg4_p2_compressor_c() {
+  if (!hack_engaged(ENGAGE_NATIVE_MPEG4))
+    mxerror("The MPEG-4 part 2 compression only works with native MPEG-4. "
+            "However, native MPEG-4 mode has not been selected with "
+            "'--engage native_mpeg4'.\n");
+
+  memory_cptr bytes(new memory_c((unsigned char *)safemalloc(4), 4, true));
+  put_uint32_be(bytes->get(), 0x000001b6);
+  set_bytes(bytes);
+}
+
+// ---------------------------------------------------------------------
+
 compressor_c::~compressor_c() {
   if (items != 0)
-    mxverb(2, "compression: Overall stats: raw size: %lld, compressed "
-           "size: %lld, items: %lld, ratio: %.2f%%, avg bytes per item: "
-           "%lld\n", raw_size, compressed_size, items,
+    mxverb(2, "compression: Overall stats: raw size: " LLD ", compressed "
+           "size: " LLD ", items: " LLD ", ratio: %.2f%%, avg bytes per item: "
+           "" LLD "\n", raw_size, compressed_size, items,
            compressed_size * 100.0 / raw_size, compressed_size / items);
 }
 
+void
+compressor_c::set_track_headers(KaxContentEncoding &c_encoding) {
+  KaxContentCompression *c_comp;
+
+  c_comp = &GetChild<KaxContentCompression>(c_encoding);
+  // Set compression method.
+  *static_cast<EbmlUInteger *>(&GetChild<KaxContentCompAlgo>(*c_comp)) =
+    compression_method_map[method];
+}
+
 compressor_ptr
 compressor_c::create(compression_method_e method) {
   if ((method <= COMPRESSION_UNSPECIFIED) ||
@@ -278,6 +377,9 @@ compressor_c::create(const char *method) {
     return compressor_ptr(new bzlib_compressor_c());
 #endif // HAVE_BZLIB_H
 
+  if (!strcasecmp(method, compression_methods[COMPRESSION_MPEG4_P2]))
+    return compressor_ptr(new mpeg4_p2_compressor_c());
+
   if (!strcasecmp(method, "none"))
     return compressor_ptr(new compressor_c(COMPRESSION_NONE));
 
@@ -286,6 +388,11 @@ compressor_c::create(const char *method) {
 
 // ------------------------------------------------------------------------
 
+kax_content_encoding_t::kax_content_encoding_t():
+  order(0), type(0), scope(CONTENT_ENCODING_SCOPE_BLOCK), comp_algo(0),
+  enc_algo(0), sig_algo(0), sig_hash_algo(0) {
+}
+
 content_decoder_c::content_decoder_c():
   ok(true) {
 }
@@ -296,16 +403,13 @@ content_decoder_c::content_decoder_c(KaxTrackEntry &ktentry):
 }
 
 content_decoder_c::~content_decoder_c() {
-  int i;
-
-  for (i = 0; i < encodings.size(); i++) {
-    safefree(encodings[i].comp_settings);
-    safefree(encodings[i].enc_keyid);
-    safefree(encodings[i].sig_keyid);
-    safefree(encodings[i].signature);
-  }
 }
 
+#define EBMLBIN_TO_COUNTEDMEM(bin) \
+  memory_cptr(new memory_c((unsigned char *)safememdup(bin->GetBuffer(), \
+                                                       bin->GetSize()), \
+                           bin->GetSize(), true))
+
 bool
 content_decoder_c::initialize(KaxTrackEntry &ktentry) {
   KaxContentEncodings *kcencodings;
@@ -359,11 +463,8 @@ content_decoder_c::initialize(KaxTrackEntry &ktentry) {
         enc.comp_algo = uint32(*cc_algo);
 
       cc_settings = FINDFIRST(ce_comp, KaxContentCompSettings);
-      if (cc_settings != NULL) {
-        enc.comp_settings = (unsigned char *)
-          safememdup(cc_settings->GetBuffer(), cc_settings->GetSize());
-        enc.comp_settings_len = cc_settings->GetSize();
-      }
+      if (cc_settings != NULL)
+        enc.comp_settings = EBMLBIN_TO_COUNTEDMEM(cc_settings);
     }
 
     ce_enc = FINDFIRST(kcenc, KaxContentEncryption);
@@ -380,11 +481,8 @@ content_decoder_c::initialize(KaxTrackEntry &ktentry) {
         enc.enc_algo = uint32(*ce_ealgo);
 
       ce_ekeyid = FINDFIRST(ce_enc, KaxContentEncKeyID);
-      if (ce_ekeyid != NULL) {
-        enc.enc_keyid = (unsigned char *)
-          safememdup(ce_ekeyid->GetBuffer(), ce_ekeyid->GetSize());
-        enc.enc_keyid_len = ce_ekeyid->GetSize();
-      }
+      if (ce_ekeyid != NULL)
+        enc.enc_keyid = EBMLBIN_TO_COUNTEDMEM(ce_ekeyid);
 
       ce_salgo = FINDFIRST(ce_enc, KaxContentSigAlgo);
       if (ce_salgo != NULL)
@@ -395,18 +493,12 @@ content_decoder_c::initialize(KaxTrackEntry &ktentry) {
         enc.enc_algo = uint32(*ce_shalgo);
 
       ce_skeyid = FINDFIRST(ce_enc, KaxContentSigKeyID);
-      if (ce_skeyid != NULL) {
-        enc.sig_keyid = (unsigned char *)
-          safememdup(ce_skeyid->GetBuffer(), ce_skeyid->GetSize());
-        enc.sig_keyid_len = ce_skeyid->GetSize();
-      }
+      if (ce_skeyid != NULL)
+        enc.sig_keyid = EBMLBIN_TO_COUNTEDMEM(ce_skeyid);
 
       ce_signature = FINDFIRST(ce_enc, KaxContentSignature);
-      if (ce_signature != NULL) {
-        enc.signature = (unsigned char *)
-          safememdup(ce_signature->GetBuffer(), ce_signature->GetSize());
-        enc.signature_len = ce_signature->GetSize();
-      }
+      if (ce_signature != NULL)
+        enc.signature = EBMLBIN_TO_COUNTEDMEM(ce_signature);
 
     }
 
@@ -431,8 +523,7 @@ content_decoder_c::initialize(KaxTrackEntry &ktentry) {
       ok = false;
       break;
 #else
-      if (NULL == zlib_compressor.get())
-        zlib_compressor = auto_ptr<compressor_c>(new zlib_compressor_c());
+      enc.compressor = counted_ptr<compressor_c>(new zlib_compressor_c());
 #endif
     } else if (1 == enc.comp_algo) {
 #if !defined(HAVE_BZLIB_H)
@@ -441,8 +532,7 @@ content_decoder_c::initialize(KaxTrackEntry &ktentry) {
       ok = false;
       break;
 #else
-      if (NULL == bzlib_compressor.get())
-        bzlib_compressor = auto_ptr<compressor_c>(new bzlib_compressor_c());
+      enc.compressor = counted_ptr<compressor_c>(new bzlib_compressor_c());
 #endif
     } else if (enc.comp_algo == 2) {
 #if !defined(HAVE_LZO1X_H)
@@ -451,9 +541,13 @@ content_decoder_c::initialize(KaxTrackEntry &ktentry) {
       ok = false;
       break;
 #else
-      if (NULL == lzo1x_compressor.get())
-        lzo1x_compressor = auto_ptr<compressor_c>(new lzo_compressor_c());
+      enc.compressor = counted_ptr<compressor_c>(new lzo_compressor_c());
 #endif
+    } else if (enc.comp_algo == 3) {
+      header_removal_compressor_c *c = new header_removal_compressor_c();
+      c->set_bytes(enc.comp_settings);
+      enc.compressor = counted_ptr<compressor_c>(c);
+
     } else {
       mxwarn("Track %d has been compressed with an unknown/unsupported "
              "compression algorithm (%d).\n", tid,
@@ -471,45 +565,15 @@ content_decoder_c::initialize(KaxTrackEntry &ktentry) {
   return ok;
 }
 
-bool
-content_decoder_c::reverse(unsigned char *&data,
-                           uint32_t &size,
+void
+content_decoder_c::reverse(memory_cptr &memory,
                            content_encoding_scope_e scope) {
-  int new_size;
-  unsigned char *new_data, *old_data;
-  bool modified;
   vector<kax_content_encoding_t>::const_iterator ce;
-  compressor_c *compressor;
 
-  if (!ok)
-    return false;
+  if (!is_ok() || encodings.empty())
+    return;
 
-  if (0 == encodings.size())
-    return false;
-
-  new_data = data;
-  new_size = size;
-  modified = false;
-  foreach(ce, encodings) {
-    if (0 == (ce->scope & scope))
-      continue;
-
-    if (ce->comp_algo == 0)
-      compressor = zlib_compressor.get();
-    else if (ce->comp_algo == 1)
-      compressor = bzlib_compressor.get();
-    else
-      compressor = lzo1x_compressor.get();
-
-    old_data = new_data;
-    new_data = compressor->decompress(old_data, new_size);
-    if (modified)
-      safefree(old_data);
-    modified = true;
-  }
-
-  data = new_data;
-  size = new_size;
-
-  return modified;
+  mxforeach(ce, encodings)
+    if (0 != (ce->scope & scope))
+      ce->compressor->decompress(memory);
 }
