@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mm_io.h 3004 2005-08-03 10:26:08Z mosu $
+   $Id: mm_io.h 3759 2008-02-27 15:32:22Z mosu $
 
    IO callback class definitions
 
@@ -20,10 +20,13 @@
 
 #include <string>
 #include <stack>
+#include <vector>
 
 #include <ebml/IOCallback.h>
 
+#include "common_memory.h"
 #include "error.h"
+#include "smart_pointers.h"
 
 using namespace std;
 using namespace libebml;
@@ -52,12 +55,12 @@ class MTX_DLL_API mm_io_c: public IOCallback {
 protected:
   bool dos_style_newlines;
   stack<int64_t> positions;
-  int64_t m_current_position;
+  int64_t m_current_position, cached_size;
 
 public:
   mm_io_c():
     dos_style_newlines(false),
-    m_current_position(0) {
+    m_current_position(0), cached_size(-1) {
   }
   virtual ~mm_io_c() { }
 
@@ -67,6 +70,7 @@ public:
   virtual bool setFilePointer2(int64 offset, seek_mode mode = seek_beginning);
   virtual uint32 read(void *buffer, size_t size) = 0;
   virtual uint32_t read(string &buffer, size_t size);
+  virtual uint32_t read(memory_cptr &buffer, size_t size, int offset = 0);
   virtual unsigned char read_uint8();
   virtual uint16_t read_uint16_le();
   virtual uint32_t read_uint24_le();
@@ -85,6 +89,7 @@ public:
   virtual int write_uint64_be(uint64_t value);
   virtual void skip(int64 numbytes);
   virtual size_t write(const void *buffer, size_t size) = 0;
+  virtual uint32_t write(const memory_cptr &buffer, int size = -1, int offset = 0);
   virtual bool eof() = 0;
   virtual void flush() {
   }
@@ -110,6 +115,8 @@ public:
   }
 };
 
+typedef counted_ptr<mm_io_c> mm_io_cptr;
+
 class MTX_DLL_API mm_file_io_c: public mm_io_c {
 protected:
 #if defined(SYS_WINDOWS)
@@ -127,6 +134,8 @@ public:
   mm_file_io_c(const string &path, const open_mode mode = MODE_READ);
   virtual ~mm_file_io_c();
 
+  static void prepare_path(const string &path);
+
   virtual uint64 getFilePointer();
 #if defined(SYS_WINDOWS)
   virtual uint64 get_real_file_pointer();
@@ -146,6 +155,8 @@ public:
   static void setup();
 };
 
+typedef counted_ptr<mm_file_io_c> mm_file_io_cptr;
+
 class MTX_DLL_API mm_proxy_io_c: public mm_io_c {
 protected:
   mm_io_c *proxy_io;
@@ -181,6 +192,8 @@ public:
   }
 };
 
+typedef counted_ptr<mm_proxy_io_c> mm_proxy_io_cptr;
+
 class MTX_DLL_API mm_null_io_c: public mm_io_c {
 protected:
   int64_t pos;
@@ -195,6 +208,8 @@ public:
   virtual void close();
 };
 
+typedef counted_ptr<mm_null_io_c> mm_null_io_cptr;
+
 class MTX_DLL_API mm_mem_io_c: public mm_io_c {
 protected:
   int64_t pos, mem_size, allocated, increase;
@@ -211,7 +226,13 @@ public:
   virtual uint64 getFilePointer();
   virtual void setFilePointer(int64 offset, seek_mode mode = seek_beginning);
   virtual uint32 read(void *buffer, size_t size);
+  virtual uint32_t read(memory_cptr &buffer, size_t size, int offset = 0) {
+    return mm_io_c::read(buffer, size, offset);
+  }
   virtual size_t write(const void *buffer, size_t size);
+  virtual uint32_t write(const memory_cptr &buffer, int size = -1, int offset = 0) {
+    return mm_io_c::write(buffer, size, offset);
+  }
   virtual void close();
   virtual bool eof();
   virtual string get_file_name() const {
@@ -220,10 +241,13 @@ public:
   virtual void set_file_name(const string &_file_name) {
     file_name = _file_name;
   }
+
+  virtual unsigned char *get_and_lock_buffer();
 };
 
-enum byte_order_e {BO_UTF8, BO_UTF16_LE, BO_UTF16_BE, BO_UTF32_LE, BO_UTF32_BE,
-                   BO_NONE};
+typedef counted_ptr<mm_mem_io_c> mm_mem_io_cptr;
+
+enum byte_order_e {BO_UTF8, BO_UTF16_LE, BO_UTF16_BE, BO_UTF32_LE, BO_UTF32_BE, BO_NONE};
 
 class MTX_DLL_API mm_text_io_c: public mm_proxy_io_c {
 protected:
@@ -242,6 +266,8 @@ public:
   }
 };
 
+typedef counted_ptr<mm_text_io_c> mm_text_io_cptr;
+
 class MTX_DLL_API mm_stdio_c: public mm_io_c {
 public:
   mm_stdio_c();
@@ -260,4 +286,6 @@ public:
   virtual void flush();
 };
 
+typedef counted_ptr<mm_stdio_c> mm_stdio_cptr;
+
 #endif // __MM_IO_H
