@@ -13,7 +13,7 @@
    licensed under the LGPL.
 
    \file
-   \version $Id: mpeg4_common.cpp 3763 2008-02-28 13:49:11Z mosu $
+   \version $Id: mpeg4_common.cpp 3855 2008-08-24 19:44:49Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
 */
@@ -971,6 +971,28 @@ mpeg4::p2::is_fourcc(const void *fourcc) {
   return false;
 }
 
+/** \brief Check whether or not a FourCC refers to MPEG-4 part 2
+    version 3 video
+
+   \param fourcc A pointer to a string with four characters
+
+   \return true if the FourCC refers to a MPEG-4 part 2 video codec.
+*/
+bool
+mpeg4::p2::is_v3_fourcc(const void *fourcc) {
+  static const char *mpeg4_p2_v3_fourccs[] = {
+    "DIV3", "MPG3", "MP43",
+    "AP41", // Angel Potion
+    NULL
+  };
+  int i;
+
+  for (i = 0; NULL != mpeg4_p2_v3_fourccs[i]; ++i)
+    if (!strncasecmp((const char *)fourcc, mpeg4_p2_v3_fourccs[i], 4))
+      return true;
+  return false;
+}
+
 // -------------------------------------------------------------------
 
 static bool
