@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: attachments.cpp 2791 2005-02-11 23:29:39Z mosu $
+   $Id: attachments.cpp 3455 2007-01-10 13:13:23Z mosu $
 
    extracts attachments from Matroska files into other files
 
@@ -23,7 +23,7 @@
 #include <time.h>
 
 #if defined(COMP_MSC)
-#include <assert.h>
+#include <cassert>
 #else
 #include <unistd.h>
 #endif
@@ -127,7 +127,13 @@ handle_attachments(KaxAttachments *atts,
         }
 
       if (found && !tracks[k].done) {
-        mxinfo(_("The attachment #%lld, MIME type %s, size %lld, "
+        // check for output name
+        if (strlen(tracks[k].out_name) == 0) {
+          safefree(tracks[k].out_name);
+          tracks[k].out_name = safestrdup(name.c_str());
+        }
+
+        mxinfo(_("The attachment #" LLD ", MIME type %s, size " LLD ", "
                  "is written to '%s'.\n"), id, type.c_str(), size,
                tracks[k].out_name);
         try {
@@ -181,6 +187,6 @@ extract_attachments(const char *file_name,
 
   for (i = 0; i < tracks.size(); i++)
     if (!tracks[i].done)
-      mxinfo(_("An attachment with the ID %lld was not found.\n"),
+      mxinfo(_("An attachment with the ID " LLD " was not found.\n"),
              tracks[i].tid);
 }
