@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_avc.cpp 3532 2007-06-23 09:16:13Z mosu $
+   $Id: xtr_avc.cpp 3754 2008-02-25 17:13:13Z mosu $
 
    extracts tracks from Matroska files into other files
 
@@ -29,11 +29,11 @@ void
 xtr_avc_c::write_nal(const binary *data,
                      int &pos,
                      int data_size,
-                     int nal_size_size) {
+                     int write_nal_size_size) {
   int i;
   int nal_size = 0;
 
-  for (i = 0; i < nal_size_size; ++i)
+  for (i = 0; i < write_nal_size_size; ++i)
     nal_size = (nal_size << 8) | data[pos++];
 
   if ((pos + nal_size) > data_size)
