@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_base.cpp 3577 2007-08-15 19:43:36Z mosu $
+   $Id: xtr_base.cpp 3834 2008-08-21 10:12:31Z mosu $
 
    extracts tracks from Matroska files into other files
 
@@ -185,6 +185,8 @@ xtr_base_c::create_extractor(const string &new_codec_id,
     return new xtr_usf_c(new_codec_id, new_tid, tspec);
   else if (new_codec_id == MKV_V_COREPICTURE)
     return new xtr_cpic_c(new_codec_id, new_tid, tspec);
+  else if (new_codec_id == MKV_S_KATE)
+    return new xtr_oggkate_c(new_codec_id, new_tid, tspec);
 
   return NULL;
 }
