@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_ogg.h 3461 2007-01-12 14:44:59Z mosu $
+   $Id: xtr_ogg.h 3834 2008-08-21 10:12:31Z mosu $
 
    extracts tracks from Matroska files into other files
 
@@ -19,6 +19,7 @@
 
 #include <ogg/ogg.h>
 
+#include "kate_common.h"
 #include "xtr_base.h"
 
 class xtr_flac_c: public xtr_base_c {
@@ -72,4 +73,20 @@ public:
   };
 };
 
+class xtr_oggkate_c: public xtr_oggbase_c {
+public:
+  xtr_oggkate_c(const string &_codec_id, int64_t _tid, track_spec_t &tspec);
+
+  virtual void create_file(xtr_base_c *_master, KaxTrackEntry &track);
+  virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref,
+                            int64_t fref, bool keyframe, bool discardable, bool references_valid);
+
+  virtual const char *get_container_name() {
+    return "Ogg (Kate in Ogg)";
+  };
+
+private:
+  kate_identification_header_t kate_id_header;
+};
+
 #endif
