@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_rmff.cpp 2859 2005-03-19 11:03:12Z mosu $
+   $Id: xtr_rmff.cpp 3532 2007-06-23 09:16:13Z mosu $
 
    extracts tracks from Matroska files into other files
 
@@ -32,8 +32,12 @@ xtr_rmff_c::create_file(xtr_base_c *_master,
 
   priv = FINDFIRST(&track, KaxCodecPrivate);
   if (NULL == priv)
-    mxerror("Track %lld with the CodecID '%s' is missing the \"codec private"
-            "\" element and cannot be extracted.\n", tid, codec_id.c_str());
+    mxerror("Track " LLD " with the CodecID '%s' is missing the \"codec "
+            "private\" element and cannot be extracted.\n", tid,
+            codec_id.c_str());
+
+  init_content_decoder(track);
+  memory_cptr mpriv = decode_codec_private(priv);
 
   master = _master;
   if (NULL == master) {
@@ -49,9 +53,7 @@ xtr_rmff_c::create_file(xtr_base_c *_master,
     mxerror("Memory allocation error: %d (%s).\n",
             rmff_last_error, rmff_last_error_msg);
 
-  rmff_set_type_specific_data(rmtrack,
-                              (const unsigned char *)priv->GetBuffer(),
-                              priv->GetSize());
+  rmff_set_type_specific_data(rmtrack, mpriv->get(), mpriv->get_size());
 
   if ('V' == codec_id[0])
     rmff_set_track_data(rmtrack, "Video", "video/x-pn-realvideo");
@@ -60,31 +62,33 @@ xtr_rmff_c::create_file(xtr_base_c *_master,
 }
 
 void
-xtr_rmff_c::handle_block(KaxBlock &block,
+xtr_rmff_c::handle_frame(memory_cptr &frame,
                          KaxBlockAdditions *additions,
                          int64_t timecode,
                          int64_t duration,
                          int64_t bref,
-                         int64_t fref) {
-  int i;
-  rmff_frame_t *frame;
+                         int64_t fref,
+                         bool keyframe,
+                         bool discardable,
+                         bool references_valid) {
+  rmff_frame_t *rmff_frame;
 
-  for (i = 0; i < block.NumberFrames(); i++) {
-    DataBuffer &data = block.GetBuffer(i);
+  content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
 
-    frame = rmff_allocate_frame(data.Size(), data.Buffer());
-    if (frame == NULL)
-      mxerror("Memory for a RealAudio/RealVideo frame could not be "
-              "allocated.\n");
-    frame->timecode = timecode / 1000000;
-    if (0 == bref)
-      frame->flags = RMFF_FRAME_FLAG_KEYFRAME;
-    if ('V' == codec_id[0])
-      rmff_write_packed_video_frame(rmtrack, frame);
-    else
-      rmff_write_frame(rmtrack, frame);
-    rmff_release_frame(frame);
-  }
+  rmff_frame = rmff_allocate_frame(frame->get_size(), frame->get());
+  if (rmff_frame == NULL)
+    mxerror("Memory for a RealAudio/RealVideo frame could not be "
+            "allocated.\n");
+  rmff_frame->timecode = timecode / 1000000;
+  if (references_valid)
+    keyframe = 0 == bref;
+  if (keyframe)
+    rmff_frame->flags = RMFF_FRAME_FLAG_KEYFRAME;
+  if ('V' == codec_id[0])
+    rmff_write_packed_video_frame(rmtrack, rmff_frame);
+  else
+    rmff_write_frame(rmtrack, rmff_frame);
+  rmff_release_frame(rmff_frame);
 }
 
 void
