@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_aac.cpp 3755 2008-02-26 19:08:38Z mosu $
+   $Id: r_aac.cpp 3861 2008-08-27 11:27:04Z mosu $
 
    AAC demultiplexer module
 
@@ -20,6 +20,7 @@
 
 #include "common.h"
 #include "error.h"
+#include "id3_common.h"
 #include "r_aac.h"
 #include "p_aac.h"
 #include "output_control.h"
@@ -37,82 +38,98 @@ aac_reader_c::probe_file(mm_io_c *io,
     return 0;
   try {
     io->setFilePointer(0, seek_beginning);
+    skip_id3v2_tag(*io);
     if (io->read(buf, PROBESIZE) != PROBESIZE)
       io->setFilePointer(0, seek_beginning);
     io->setFilePointer(0, seek_beginning);
   } catch (...) {
     return 0;
   }
+
   if (parse_aac_adif_header(buf, PROBESIZE, &aacheader))
     return 1;
+
   pos = find_aac_header(buf, PROBESIZE, &aacheader, false);
-  if ((pos < 0) || ((pos + aacheader.bytes) >= PROBESIZE)) {
+  if ((0 > pos) || ((pos + aacheader.bytes) >= PROBESIZE)) {
     pos = find_aac_header(buf, PROBESIZE, &aacheader, true);
-    if ((pos < 0) || ((pos + aacheader.bytes) >= PROBESIZE))
+    if ((0 > pos) || ((pos + aacheader.bytes) >= PROBESIZE))
       return 0;
-    pos = find_aac_header(&buf[pos + aacheader.bytes], PROBESIZE - pos -
-                          aacheader.bytes, &aacheader, true);
-    if (pos != 0)
+    pos = find_aac_header(&buf[pos + aacheader.bytes], PROBESIZE - pos - aacheader.bytes, &aacheader, true);
+    if (0 != pos)
       return 0;
   }
-  pos = find_aac_header(&buf[pos + aacheader.bytes], PROBESIZE - pos -
-                        aacheader.bytes, &aacheader, false);
-  if (pos != 0)
+
+  pos = find_aac_header(&buf[pos + aacheader.bytes], PROBESIZE - pos - aacheader.bytes, &aacheader, false);
+  if (0 != pos)
     return 0;
 
   return 1;
 }
 
-#define INITCHUNKSIZE 16384
+#define INITCHUNKSIZE   16384
 #define SINITCHUNKSIZE "16384"
 
 aac_reader_c::aac_reader_c(track_info_c &_ti)
   throw (error_c):
   generic_reader_c(_ti),
   sbr_status_set(false) {
+
   int adif, detected_profile;
 
   try {
-    io = new mm_file_io_c(ti.fname);
-    size = io->get_size();
-    chunk = (unsigned char *)safemalloc(INITCHUNKSIZE);
-    if (io->read(chunk, INITCHUNKSIZE) != INITCHUNKSIZE)
-      throw error_c("aac_reader: Could not read " SINITCHUNKSIZE " bytes.");
-    io->setFilePointer(0, seek_beginning);
-    if (parse_aac_adif_header(chunk, INITCHUNKSIZE, &aacheader)) {
+    io                 = new mm_file_io_c(ti.fname);
+    size               = io->get_size();
+
+    int tag_size_start = skip_id3v2_tag(*io);
+    int tag_size_end   = id3_tag_present_at_end(*io);
+
+    if (0 > tag_size_start)
+      tag_size_start = 0;
+    if (0 < tag_size_end)
+      size -= tag_size_end;
+
+    int init_read_len = MXMIN(size - tag_size_start, INITCHUNKSIZE);
+    chunk             = (unsigned char *)safemalloc(INITCHUNKSIZE);
+
+    if (io->read(chunk, init_read_len) != init_read_len)
+      throw error_c(mxsprintf("aac_reader: Could not read %d bytes.", init_read_len));
+
+    io->setFilePointer(tag_size_start, seek_beginning);
+
+    if (parse_aac_adif_header(chunk, init_read_len, &aacheader)) {
       throw error_c("aac_reader: ADIF header files are not supported.");
       adif = 1;
+
     } else {
-      if (find_aac_header(chunk, INITCHUNKSIZE, &aacheader, emphasis_present)
-          != 0)
-        throw error_c("aac_reader: No valid AAC packet found in the first "
-                      SINITCHUNKSIZE " bytes.\n");
+      if (find_aac_header(chunk, init_read_len, &aacheader, emphasis_present) != 0)
+        throw error_c(mxsprintf("aac_reader: No valid AAC packet found in the first %d bytes.\n", init_read_len));
       guess_adts_version();
       adif = 0;
     }
-    bytes_processed = 0;
-    ti.id = 0;                 // ID for this track.
 
+    ti.id            = 0;       // ID for this track.
+    bytes_processed  = 0;
     detected_profile = aacheader.profile;
 
     if (24000 >= aacheader.sample_rate)
       aacheader.profile = AAC_PROFILE_SBR;
 
-    if ((map_has_key(ti.all_aac_is_sbr, 0) && ti.all_aac_is_sbr[0]) ||
-        (map_has_key(ti.all_aac_is_sbr, -1) && ti.all_aac_is_sbr[-1]))
+    if (   (map_has_key(ti.all_aac_is_sbr,  0) && ti.all_aac_is_sbr[ 0])
+        || (map_has_key(ti.all_aac_is_sbr, -1) && ti.all_aac_is_sbr[-1]))
       aacheader.profile = AAC_PROFILE_SBR;
 
-    if ((map_has_key(ti.all_aac_is_sbr, 0) && !ti.all_aac_is_sbr[0]) ||
-        (map_has_key(ti.all_aac_is_sbr, -1) && !ti.all_aac_is_sbr[-1]))
+    if (   (map_has_key(ti.all_aac_is_sbr,  0) && !ti.all_aac_is_sbr[ 0])
+        || (map_has_key(ti.all_aac_is_sbr, -1) && !ti.all_aac_is_sbr[-1]))
       aacheader.profile = detected_profile;
 
-    if (map_has_key(ti.all_aac_is_sbr, 0) ||
-        map_has_key(ti.all_aac_is_sbr, -1))
+    if (   map_has_key(ti.all_aac_is_sbr,  0)
+        || map_has_key(ti.all_aac_is_sbr, -1))
       sbr_status_set = true;
 
   } catch (...) {
     throw error_c("aac_reader: Could not open the file.");
   }
+
   if (verbose)
     mxinfo(FMT_FN "Using the AAC demultiplexer.\n", ti.fname.c_str());
 }
@@ -135,22 +152,19 @@ aac_reader_c::create_packetizer(int64_t) {
            "file actually contains SBR AAC. The file will be muxed in the "
            "WRONG way otherwise. Also read mkvmerge's documentation.\n");
 
-  aacpacketizer = new aac_packetizer_c(this, aacheader.id, aacheader.profile,
-                                       aacheader.sample_rate,
-                                       aacheader.channels, ti,
-                                       emphasis_present);
+  aacpacketizer = new aac_packetizer_c(this, aacheader.id, aacheader.profile, aacheader.sample_rate, aacheader.channels, ti, emphasis_present);
   add_packetizer(aacpacketizer);
-  if (aacheader.profile == AAC_PROFILE_SBR)
+
+  if (AAC_PROFILE_SBR == aacheader.profile)
     aacpacketizer->set_audio_output_sampling_freq(aacheader.sample_rate * 2);
-  mxinfo(FMT_TID "Using the AAC output module.\n", ti.fname.c_str(),
-         (int64_t)0);
+
+  mxinfo(FMT_TID "Using the AAC output module.\n", ti.fname.c_str(), (int64_t)0);
 }
 
 // Try to guess if the MPEG4 header contains the emphasis field (2 bits)
 void
 aac_reader_c::guess_adts_version() {
   aac_header_t tmp_aacheader;
-  int pos;
 
   emphasis_present = false;
 
@@ -166,8 +180,8 @@ aac_reader_c::guess_adts_version() {
   }
 
   // Looks ok so far. See if the next ADTS is right behind this packet.
-  pos = find_aac_header(&chunk[tmp_aacheader.bytes], INITCHUNKSIZE - tmp_aacheader.bytes, &tmp_aacheader, emphasis_present);
-  if (pos != 0) {               // Not ok - what do we do now?
+  int pos = find_aac_header(&chunk[tmp_aacheader.bytes], INITCHUNKSIZE - tmp_aacheader.bytes, &tmp_aacheader, emphasis_present);
+  if (0 != pos) {               // Not ok - what do we do now?
     emphasis_present = true;
     return;
   }
@@ -176,17 +190,24 @@ aac_reader_c::guess_adts_version() {
 file_status_e
 aac_reader_c::read(generic_packetizer_c *,
                    bool) {
-  int nread;
+  int remaining_bytes = size - io->getFilePointer();
+  int read_len        = MXMIN(INITCHUNKSIZE, remaining_bytes);
+  int num_read        = io->read(chunk, read_len);
 
-  nread = io->read(chunk, 4096);
-  if (nread <= 0) {
+  if (0 > num_read) {
     PTZR0->flush();
     return FILE_STATUS_DONE;
   }
-  PTZR0->process(new packet_t(new memory_c(chunk, nread, false)));
-  bytes_processed += nread;
 
-  return FILE_STATUS_MOREDATA;
+  PTZR0->process(new packet_t(new memory_c(chunk, num_read, false)));
+  bytes_processed += num_read;
+
+  if (0 < (remaining_bytes - num_read))
+    return FILE_STATUS_MOREDATA;
+
+  PTZR0->flush();
+
+  return FILE_STATUS_DONE;
 }
 
 int
