@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_avi.h 3409 2007-01-02 12:17:12Z mosu $
+   $Id: r_avi.h 3855 2008-08-24 19:44:49Z mosu $
 
    class definitions for the AVI demultiplexer module
 
@@ -73,6 +73,9 @@ protected:
   virtual file_status_e read_video();
   virtual file_status_e read_audio(avi_demuxer_t &demuxer);
   virtual memory_cptr extract_avcc();
+
+  virtual generic_packetizer_c *create_aac_packetizer(int aid, avi_demuxer_t &demuxer);
+  virtual generic_packetizer_c *create_vorbis_packetizer(int aid);
 };
 
 #endif  // __R_AVI_H
