@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_flac.h 2809 2005-02-24 21:05:35Z mosu $
+   $Id: r_flac.h 3830 2008-08-19 14:52:12Z mosu $
 
    class definitions for the raw FLAC stream reader
 
@@ -23,7 +23,17 @@
 #if defined(HAVE_FLAC_FORMAT_H)
 #include <vector>
 
-#include <FLAC/seekable_stream_decoder.h>
+#include <FLAC/export.h>
+#if !defined(FLAC_API_VERSION_CURRENT) || FLAC_API_VERSION_CURRENT < 8
+# define LEGACY_FLAC
+#else
+# undef LEGACY_FLAC
+#endif
+#ifdef LEGACY_FLAC
+# include <FLAC/seekable_stream_decoder.h>
+#else
+# include <FLAC/stream_decoder.h>
+#endif
 
 #include "p_flac.h"
 
@@ -59,20 +69,31 @@ public:
 
   static int probe_file(mm_io_c *io, int64_t size);
 
+#ifdef LEGACY_FLAC
   virtual FLAC__SeekableStreamDecoderReadStatus
   read_cb(FLAC__byte buffer[], unsigned *bytes);
+#else
+  virtual FLAC__StreamDecoderReadStatus
+  read_cb(FLAC__byte buffer[], size_t *bytes);
+#endif
 
   virtual FLAC__StreamDecoderWriteStatus
   write_cb(const FLAC__Frame *frame, const FLAC__int32 * const data[]);
 
   virtual void metadata_cb(const FLAC__StreamMetadata *metadata);
   virtual void error_cb(FLAC__StreamDecoderErrorStatus status);
+#ifdef LEGACY_FLAC
   virtual FLAC__SeekableStreamDecoderSeekStatus
   seek_cb(uint64_t new_pos);
   virtual FLAC__SeekableStreamDecoderTellStatus
   tell_cb(uint64_t &absolute_byte_offset);
   virtual FLAC__SeekableStreamDecoderLengthStatus
   length_cb(uint64_t &stream_length);
+#else
+  virtual FLAC__StreamDecoderSeekStatus seek_cb(uint64_t new_pos);
+  virtual FLAC__StreamDecoderTellStatus tell_cb(uint64_t &absolute_byte_offset);
+  virtual FLAC__StreamDecoderLengthStatus length_cb(uint64_t &stream_length);
+#endif
   virtual FLAC__bool eof_cb();
 
 protected:
@@ -81,9 +102,12 @@ protected:
 
 #else  // HAVE_FLAC_FORMAT_H
 
-class flac_reader_c {
+class flac_reader_c: public generic_reader_c {
 public:
   static int probe_file(mm_io_c *file, int64_t size);
+
+public:
+  flac_reader_c(track_info_c &n_ti): generic_reader_c(n_ti) { };
 };
 
 #endif // HAVE_FLAC_FORMAT_H
