@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_tta.cpp 3755 2008-02-26 19:08:38Z mosu $
+   $Id: r_tta.cpp 3865 2008-08-27 20:38:43Z mosu $
 
    TTA demultiplexer module
 
@@ -28,15 +28,14 @@
 int
 tta_reader_c::probe_file(mm_io_c *io,
                          int64_t size) {
-  int tag_size;
   unsigned char buf[4];
 
-  if (size < 26)
+  if (26 > size)
     return 0;
   try {
     io->setFilePointer(0, seek_beginning);
-    tag_size = skip_id3v2_tag(*io);
-    if (tag_size == -1)
+    int tag_size = skip_id3v2_tag(*io);
+    if (-1 == tag_size)
       return 0;
     if (io->read(buf, 4) != 4)
       return 0;
@@ -52,37 +51,34 @@ tta_reader_c::probe_file(mm_io_c *io,
 tta_reader_c::tta_reader_c(track_info_c &_ti)
   throw (error_c):
   generic_reader_c(_ti) {
-  uint32_t seek_point;
-  int64_t seek_sum;
-  int tag_size;
 
   try {
-    io = new mm_file_io_c(ti.fname);
+    io   = new mm_file_io_c(ti.fname);
     size = io->get_size();
 
     if (identifying)
       return;
 
-    tag_size = skip_id3v2_tag(*io);
-    if (tag_size < 0)
+    int tag_size = skip_id3v2_tag(*io);
+    if (0 > tag_size)
       mxerror(_("tta_reader: tag_size < 0 in the c'tor. %s\n"), BUGMSG);
     size -= tag_size;
 
-    if (io->read(&header, sizeof(tta_file_header_t)) !=
-        sizeof(tta_file_header_t))
+    if (io->read(&header, sizeof(tta_file_header_t)) != sizeof(tta_file_header_t))
       mxerror(FMT_FN "The file header is too short.\n", ti.fname.c_str());
-    seek_sum = io->getFilePointer() + 4 - tag_size;
 
-    size -= id3_tag_present_at_end(*io);
+    int64_t seek_sum  = io->getFilePointer() + 4 - tag_size;
+    size             -= id3_tag_present_at_end(*io);
+
+    uint32_t seek_point;
 
     do {
-      seek_point = io->read_uint32_le();
-      seek_sum += seek_point + 4;
+      seek_point  = io->read_uint32_le();
+      seek_sum   += seek_point + 4;
       seek_points.push_back(seek_point);
     } while (seek_sum < size);
 
-    mxverb(2, "tta: ch %u bps %u sr %u dl %u seek_sum " LLD " size " LLD
-           " num %u\n",
+    mxverb(2, "tta: ch %u bps %u sr %u dl %u seek_sum " LLD " size " LLD " num %u\n",
            get_uint16_le(&header.channels),
            get_uint16_le(&header.bits_per_sample),
            get_uint32_le(&header.sample_rate),
@@ -90,14 +86,13 @@ tta_reader_c::tta_reader_c(track_info_c &_ti)
            seek_sum, size, (unsigned int)seek_points.size());
 
     if (seek_sum != size)
-      mxerror(FMT_FN "The seek table in this TTA file seems to be broken.\n",
-              ti.fname.c_str());
+      mxerror(FMT_FN "The seek table in this TTA file seems to be broken.\n", ti.fname.c_str());
 
     io->skip(4);
 
     bytes_processed = 0;
-    pos = 0;
-    ti.id = 0;                 // ID for this track.
+    pos             = 0;
+    ti.id           = 0;        // ID for this track.
 
   } catch (...) {
     throw error_c("tta_reader: Could not open the file.");
@@ -112,52 +107,40 @@ tta_reader_c::~tta_reader_c() {
 
 void
 tta_reader_c::create_packetizer(int64_t) {
-  generic_packetizer_c *ttapacketizer;
-
   if (NPTZR() != 0)
     return;
-  ttapacketizer = new tta_packetizer_c(this, get_uint16_le(&header.channels),
-                                       get_uint16_le(&header.bits_per_sample),
-                                       get_uint32_le(&header.sample_rate), ti);
-  add_packetizer(ttapacketizer);
-  mxinfo(FMT_TID "Using the TTA output module.\n", ti.fname.c_str(),
-         (int64_t)0);
+
+  add_packetizer(new tta_packetizer_c(this, get_uint16_le(&header.channels), get_uint16_le(&header.bits_per_sample), get_uint32_le(&header.sample_rate), ti));
+  mxinfo(FMT_TID "Using the TTA output module.\n", ti.fname.c_str(), (int64_t)0);
 }
 
 file_status_e
 tta_reader_c::read(generic_packetizer_c *,
                    bool) {
-  unsigned char *buf;
-  int nread;
-
-  if (pos >= seek_points.size())
+  if (seek_points.size() <= pos)
     return FILE_STATUS_DONE;
 
-  buf = (unsigned char *)safemalloc(seek_points[pos]);
-  nread = io->read(buf, seek_points[pos]);
-  if (nread <= 0) {
+  unsigned char *buf = (unsigned char *)safemalloc(seek_points[pos]);
+  int nread          = io->read(buf, seek_points[pos]);
+
+  if (0 >= nread) {
     PTZR0->flush();
     return FILE_STATUS_DONE;
   }
   pos++;
 
   memory_cptr mem(new memory_c(buf, nread, true));
-  if (pos >= seek_points.size()) {
-    double samples_left;
-
-    samples_left = (double)get_uint32_le(&header.data_length) -
-      (seek_points.size() - 1) * TTA_FRAME_TIME *
-      get_uint32_le(&header.sample_rate);
+  if (seek_points.size() <= pos) {
+    double samples_left = (double)get_uint32_le(&header.data_length) - (seek_points.size() - 1) * TTA_FRAME_TIME * get_uint32_le(&header.sample_rate);
     mxverb(2, "tta: samples_left %f\n", samples_left);
 
-    PTZR0->process(new packet_t(mem, -1,
-                                irnd(samples_left * 1000000000.0l /
-                                     get_uint32_le(&header.sample_rate))));
+    PTZR0->process(new packet_t(mem, -1, irnd(samples_left * 1000000000.0l / get_uint32_le(&header.sample_rate))));
   } else
     PTZR0->process(new packet_t(mem));
+
   bytes_processed += nread;
 
-  if (pos >= seek_points.size()) {
+  if (seek_points.size() <= pos) {
     PTZR0->flush();
     return FILE_STATUS_DONE;
   }
