@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_vobbtn.cpp 3755 2008-02-26 19:08:38Z mosu $
+   $Id: r_vobbtn.cpp 3867 2008-08-28 10:04:21Z mosu $
 
    VobBtn stream reader
 
@@ -41,11 +41,9 @@ vobbtn_reader_c::probe_file(mm_io_c *io,
       return 0;
     if (strncasecmp((char*)chunk, "butonDVD", 8))
       return 0;
-    if ((chunk[0x10] != 0x00) || (chunk[0x11] != 0x00) ||
-        (chunk[0x12] != 0x01) || (chunk[0x13] != 0xBF))
+    if ((0x00 != chunk[0x10]) || (0x00 != chunk[0x11]) || (0x01 != chunk[0x12]) || (0xBF != chunk[0x13]))
       return 0;
-    if ((chunk[0x14] != 0x03) || (chunk[0x15] != 0xD4) ||
-        (chunk[0x16] != 0x00))
+    if ((0x03 != chunk[0x14]) || (0xD4 != chunk[0x15]) || (0x00 != chunk[0x16]))
       return 0;
     io->setFilePointer(0, seek_beginning);
   } catch (...) {
@@ -60,7 +58,7 @@ vobbtn_reader_c::vobbtn_reader_c(track_info_c &_ti)
 
   try {
     btn_file = new mm_file_io_c(ti.fname);
-    size = btn_file->get_size();
+    size     = btn_file->get_size();
   } catch (...) {
     string emsg = PFX "Could not open the button file '";
     emsg += ti.fname;
@@ -70,7 +68,7 @@ vobbtn_reader_c::vobbtn_reader_c(track_info_c &_ti)
 
   // read the width & height
   btn_file->setFilePointer(8, seek_beginning);
-  width = btn_file->read_uint16_be();
+  width  = btn_file->read_uint16_be();
   height = btn_file->read_uint16_be();
   // get ready to read
   btn_file->setFilePointer(16, seek_beginning);
@@ -93,20 +91,18 @@ vobbtn_reader_c::create_packetizer(int64_t tid) {
 file_status_e
 vobbtn_reader_c::read(generic_packetizer_c *ptzr,
                       bool force) {
-  uint8_t _tmp[4];
-  int nread;
-  uint16_t frame_size;
+  uint8_t tmp[4];
 
   // _todo_ add some tests on the header and size
-  nread = btn_file->read(_tmp, 4);
-  if (nread <= 0) {
+  int nread = btn_file->read(tmp, 4);
+  if (0 >= nread) {
     PTZR0->flush();
     return FILE_STATUS_DONE;
   }
-  frame_size = btn_file->read_uint16_be();
 
-  nread = btn_file->read(chunk, frame_size);
-  if (nread <= 0) {
+  uint16_t frame_size = btn_file->read_uint16_be();
+  nread               = btn_file->read(chunk, frame_size);
+  if (0 >= nread) {
     PTZR0->flush();
     return FILE_STATUS_DONE;
   }
