@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_wav.cpp 3772 2008-02-29 16:02:10Z mosu $
+   $Id: r_wav.cpp 3867 2008-08-28 10:04:21Z mosu $
 
    WAV reader module
 
@@ -152,9 +152,10 @@ class wav_pcm_demuxer_c: public wav_demuxer_c {
 private:
   int m_bps;
   memory_cptr m_buffer;
+  bool ieee_float;
 
 public:
-  wav_pcm_demuxer_c(wav_reader_c *reader, wave_header *wheader);
+  wav_pcm_demuxer_c(wav_reader_c *reader, wave_header *wheader, bool _float);
 
   virtual ~wav_pcm_demuxer_c();
 
@@ -235,7 +236,7 @@ wav_ac3acm_demuxer_c::create_packetizer() {
 
 void
 wav_ac3acm_demuxer_c::process(int64_t size) {
-  if (size <= 0)
+  if (0 >= size)
     return;
 
   decode_buffer(size);
@@ -271,33 +272,33 @@ wav_ac3wav_demuxer_c::decode_buffer(int len) {
     return -1;
 
   if (m_swap_bytes) {
-    memcpy(      m_buf[m_cur_buf ^ 1]->get(),           m_buf[m_cur_buf]->get(),         8);
-    swab((char *)m_buf[m_cur_buf]->get() + 8,   (char *)m_buf[m_cur_buf ^ 1]->get() + 8, len - 8);
+    memcpy(      m_buf[m_cur_buf ^ 1]->get(),         m_buf[m_cur_buf]->get(),         8);
+    swab((char *)m_buf[m_cur_buf]->get() + 8, (char *)m_buf[m_cur_buf ^ 1]->get() + 8, len - 8);
     m_cur_buf ^= 1;
   }
 
   unsigned char *base = m_buf[m_cur_buf]->get();
 
-  if ((get_uint16_le(&base[0]) != AC3WAV_SYNC_WORD1) || (get_uint16_le(&base[2]) != AC3WAV_SYNC_WORD2) || (base[4] != 0x01))
+  if ((get_uint16_le(&base[0]) != AC3WAV_SYNC_WORD1) || (get_uint16_le(&base[2]) != AC3WAV_SYNC_WORD2) || (0x01 != base[4]))
     return -1;
 
   int payload_len = get_uint16_le(&base[6]) / 8;
 
-  if (len < (payload_len + 8))
+  if ((payload_len + 8) > len)
     return -1;
 
   int pos = find_ac3_header(&base[8], payload_len, &m_ac3header);
 
-  return pos == 0 ? payload_len : -1;
+  return 0 == pos ? payload_len : -1;
 }
 
 void
 wav_ac3wav_demuxer_c::process(int64_t size) {
-  if (size <= 0)
+  if (0 >= size)
     return;
 
   long dec_len = decode_buffer(size);
-  if (dec_len > 0)
+  if (0 < dec_len)
     m_ptzr->process(new packet_t(new memory_c(m_buf[m_cur_buf]->get() + 8, dec_len, false)));
 }
 
@@ -367,7 +368,7 @@ wav_dts_demuxer_c::create_packetizer() {
 
 void
 wav_dts_demuxer_c::process(int64_t size) {
-  if (size <= 0)
+  if (0 >= size)
     return;
 
   long dec_len = decode_buffer(size);
@@ -377,9 +378,11 @@ wav_dts_demuxer_c::process(int64_t size) {
 // ----------------------------------------------------------
 
 wav_pcm_demuxer_c::wav_pcm_demuxer_c(wav_reader_c *reader,
-                                     wave_header  *wheader):
+                                     wave_header  *wheader,
+                                     bool _float):
   wav_demuxer_c(reader, wheader),
-  m_bps(0) {
+  m_bps(0),
+  ieee_float(_float) {
 
   m_bps    = get_uint16_le(&m_wheader->common.wChannels) * get_uint16_le(&m_wheader->common.wBitsPerSample) * get_uint32_le(&m_wheader->common.dwSamplesPerSec) / 8;
   m_buffer = memory_c::alloc(m_bps);
@@ -394,7 +397,7 @@ wav_pcm_demuxer_c::create_packetizer() {
                                 get_uint32_le(&m_wheader->common.dwSamplesPerSec),
                                 get_uint16_le(&m_wheader->common.wChannels),
                                 get_uint16_le(&m_wheader->common.wBitsPerSample),
-                                m_reader->ti);
+                                m_reader->ti, false, ieee_float);
 
   mxinfo(FMT_TID "Using the PCM output module.\n", m_reader->ti.fname.c_str(), (int64_t)0);
 
@@ -403,7 +406,7 @@ wav_pcm_demuxer_c::create_packetizer() {
 
 void
 wav_pcm_demuxer_c::process(int64_t len) {
-  if (len <= 0)
+  if (0 >= len)
     return;
 
   m_ptzr->process(new packet_t(new memory_c(m_buffer->get(), len, false)));
@@ -416,7 +419,7 @@ wav_reader_c::probe_file(mm_io_c *io,
                          int64_t size) {
   wave_header wheader;
 
-  if (size < sizeof(wave_header))
+  if (sizeof(wave_header) > size)
     return 0;
   try {
     io->setFilePointer(0, seek_beginning);
@@ -494,6 +497,7 @@ wav_reader_c::create_demuxer() {
   ti.id = 0;                    // ID for this track.
 
   uint16_t format_tag = get_uint16_le(&m_wheader.common.wFormatTag);
+  bool ieee_float     = 0x0003 == format_tag;
 
   if (0x2000 == format_tag) {
     m_demuxer = wav_demuxer_cptr(new wav_ac3acm_demuxer_c(this, &m_wheader));
@@ -514,7 +518,7 @@ wav_reader_c::create_demuxer() {
   }
 
   if (!m_demuxer.get())
-    m_demuxer = wav_demuxer_cptr(new wav_pcm_demuxer_c(this, &m_wheader));
+    m_demuxer = wav_demuxer_cptr(new wav_pcm_demuxer_c(this, &m_wheader, ieee_float));
 
   if (verbose)
     mxinfo(FMT_FN "Using the WAV demultiplexer.\n", ti.fname.c_str());
@@ -537,7 +541,7 @@ wav_reader_c::read(generic_packetizer_c *,
 
   num_read = m_io->read(buffer, requested_bytes);
 
-  if (num_read <= 0) {
+  if (0 >= num_read) {
     PTZR0->flush();
     return FILE_STATUS_DONE;
   }
@@ -568,6 +572,8 @@ wav_reader_c::scan_chunks() {
   wav_chunk_t new_chunk;
 
   try {
+    int64_t file_size = m_io->get_size();
+
     while (true) {
       new_chunk.pos = m_io->getFilePointer();
 
@@ -576,11 +582,26 @@ wav_reader_c::scan_chunks() {
 
       new_chunk.len = m_io->read_uint32_le();
 
-      m_chunks.push_back(new_chunk);
+      mxverb(2, "wav_reader_c::scan_chunks() new chunk at " LLD " type %s length " LLD "\n",
+             new_chunk.pos, get_displayable_string(new_chunk.id, 4).c_str(), new_chunk.len);
 
       if (!strncasecmp(new_chunk.id, "data", 4))
         m_bytes_in_data_chunks += new_chunk.len;
 
+      else if (!m_chunks.empty() && !strncasecmp(m_chunks.back().id, "data", 4) && (file_size > 0x100000000ll)) {
+        wav_chunk_t &previous_chunk  = m_chunks.back();
+        int64_t this_chunk_len       = file_size - previous_chunk.pos - sizeof(struct chunk_struct);
+        m_bytes_in_data_chunks      -= previous_chunk.len;
+        m_bytes_in_data_chunks      += this_chunk_len;
+        previous_chunk.len           = this_chunk_len;
+
+        mxverb(2, "wav_reader_c::scan_chunks() hugh data chunk with wrong length at " LLD "; re-calculated from file size; new length " LLD "\n",
+               previous_chunk.pos, previous_chunk.len);
+
+        break;
+      }
+
+      m_chunks.push_back(new_chunk);
       m_io->setFilePointer(new_chunk.len, seek_current);
 
     }
