@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_wavpack.cpp 3755 2008-02-26 19:08:38Z mosu $
+   $Id: r_wavpack.cpp 3867 2008-08-28 10:04:21Z mosu $
 
    WAVPACK demultiplexer module
 
@@ -39,6 +39,7 @@ wavpack_reader_c::probe_file(mm_io_c *io,
   } catch (...) {
     return 0;
   }
+
   if (!strncmp(header.ck_id, "wvpk", 4)) {
     header.version = get_uint16_le(&header.version);
     if ((header.version >> 8) == 4)
@@ -50,47 +51,41 @@ wavpack_reader_c::probe_file(mm_io_c *io,
 wavpack_reader_c::wavpack_reader_c(track_info_c &_ti)
   throw (error_c):
   generic_reader_c(_ti) {
-  int32_t packet_size;
 
   try {
-    io = new mm_file_io_c(ti.fname);
-    size = io->get_size();
+    io              = new mm_file_io_c(ti.fname);
+    size            = io->get_size();
 
-    packet_size = wv_parse_frame(io, header, meta, true, true);
-    if (packet_size < 0)
-      mxerror(FMT_FN "The file header was not read correctly.\n",
-              ti.fname.c_str());
+    int packet_size = wv_parse_frame(io, header, meta, true, true);
+    if (0 > packet_size)
+      mxerror(FMT_FN "The file header was not read correctly.\n", ti.fname.c_str());
   } catch (...) {
     throw error_c("wavpack_reader: Could not open the file.");
   }
 
-  io->setFilePointer(io->getFilePointer() - sizeof(wavpack_header_t),
-                     seek_beginning);
+  io->setFilePointer(io->getFilePointer() - sizeof(wavpack_header_t), seek_beginning);
 
   // correction file if applies
-  io_correc = NULL;
+  io_correc           = NULL;
   meta.has_correction = false;
+
   try {
     if (header.flags & WV_HYBRID_FLAG) {
-      io_correc = new mm_file_io_c(ti.fname + "c");
-      packet_size = wv_parse_frame(io_correc, header_correc, meta_correc,
-                                   true, true);
-      if (packet_size < 0)
-        mxerror(FMT_FN "The correction file header was not read correctly.\n",
-                ti.fname.c_str());
-      io_correc->setFilePointer(io_correc->getFilePointer() -
-                                sizeof(wavpack_header_t), seek_beginning);
+      io_correc       = new mm_file_io_c(ti.fname + "c");
+      int packet_size = wv_parse_frame(io_correc, header_correc, meta_correc, true, true);
+      if (0 > packet_size)
+        mxerror(FMT_FN "The correction file header was not read correctly.\n", ti.fname.c_str());
+
+      io_correc->setFilePointer(io_correc->getFilePointer() - sizeof(wavpack_header_t), seek_beginning);
       meta.has_correction = true;
     }
   } catch (...) {
     if (verbose)
-      mxinfo(FMT_FN "Could not open the corresponding correction file '%s'.\n",
-             ti.fname.c_str(), (ti.fname + "c").c_str());
+      mxinfo(FMT_FN "Could not open the corresponding correction file '%s'.\n", ti.fname.c_str(), (ti.fname + "c").c_str());
   }
 
   if (verbose)
-    mxinfo(FMT_FN "Using the WAVPACK demultiplexer%s.\n", ti.fname.c_str(),
-           meta.has_correction ? " with a correction file" : "");
+    mxinfo(FMT_FN "Using the WAVPACK demultiplexer%s.\n", ti.fname.c_str(), meta.has_correction ? " with a correction file" : "");
 }
 
 wavpack_reader_c::~wavpack_reader_c() {
@@ -104,14 +99,14 @@ wavpack_reader_c::create_packetizer(int64_t) {
 
   if (NPTZR() != 0)
     return;
+
   put_uint16_le(&version_le, header.version);
   ti.private_data = (unsigned char *)&version_le;
   ti.private_size = sizeof(uint16_t);
   add_packetizer(new wavpack_packetizer_c(this, meta, ti));
   ti.private_data = NULL;
 
-  mxinfo(FMT_TID "Using the WAVPACK output module.\n", ti.fname.c_str(),
-         (int64_t)0);
+  mxinfo(FMT_TID "Using the WAVPACK output module.\n", ti.fname.c_str(), (int64_t)0);
 }
 
 file_status_e
@@ -130,7 +125,7 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
   while (dummy_meta.channel_count < meta.channel_count) {
     extra_frames_number++;
     block_size = wv_parse_frame(io, dummy_header, dummy_meta, false, false);
-    if (block_size == -1) {
+    if (-1 == block_size) {
       PTZR0->flush();
       return FILE_STATUS_DONE;
     }
@@ -138,7 +133,7 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
     io->skip(block_size);
   }
 
-  if (data_size < 0) {
+  if (0 > data_size) {
     PTZR0->flush();
     return FILE_STATUS_DONE;
   }
@@ -154,14 +149,14 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
   io->setFilePointer(initial_position);
 
   dummy_meta.channel_count = 0;
-  databuffer = &chunk[4];
+  databuffer               = &chunk[4];
   while (dummy_meta.channel_count < meta.channel_count) {
     block_size = wv_parse_frame(io, dummy_header, dummy_meta, false, false);
     put_uint32_le(databuffer, dummy_header.flags);
     databuffer += 4;
     put_uint32_le(databuffer, dummy_header.crc);
     databuffer += 4;
-    if (meta.channel_count > 2) {
+    if (2 < meta.channel_count) {
       // not stored for the last block
       put_uint32_le(databuffer, block_size);
       databuffer += 4;
@@ -178,16 +173,16 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
   // find the if there is a correction file data corresponding
   if (io_correc) {
     do {
-      initial_position = io_correc->getFilePointer();
+      initial_position         = io_correc->getFilePointer();
       // determine the final data size
-      data_size = 0;
-      extra_frames_number = 0;
+      data_size                = 0;
+      extra_frames_number      = 0;
       dummy_meta.channel_count = 0;
+
       while (dummy_meta.channel_count < meta_correc.channel_count) {
         extra_frames_number++;
-        block_size = wv_parse_frame(io_correc, dummy_header_correc,
-                                    dummy_meta, false, false);
-        if (block_size == -1) {
+        block_size = wv_parse_frame(io_correc, dummy_header_correc, dummy_meta, false, false);
+        if (-1 == block_size) {
           PTZR0->flush();
           return FILE_STATUS_DONE;
         }
@@ -196,7 +191,7 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
       }
 
       // no more correction to be found
-      if (data_size < 0) {
+      if (0 > data_size) {
         delete io_correc;
         io_correc = NULL;
         dummy_header_correc.block_samples = dummy_header.block_samples + 1;
@@ -205,7 +200,6 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
     } while (dummy_header_correc.block_samples < dummy_header.block_samples);
 
     if (dummy_header_correc.block_samples == dummy_header.block_samples) {
-      uint8_t *chunk_correc;
 
       io_correc->setFilePointer(initial_position);
 
@@ -213,17 +207,17 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
         data_size += extra_frames_number * 2 * sizeof(uint32_t);
       else
         data_size += sizeof(uint32_t);
-      chunk_correc = (uint8_t *)safemalloc(data_size);
 
+      uint8_t *chunk_correc    = (uint8_t *)safemalloc(data_size);
       // only keep the CRC in the header
       dummy_meta.channel_count = 0;
-      databuffer = chunk_correc;
+      databuffer               = chunk_correc;
+
       while (dummy_meta.channel_count < meta_correc.channel_count) {
-        block_size = wv_parse_frame(io_correc, dummy_header_correc,
-                                    dummy_meta, false, false);
+        block_size = wv_parse_frame(io_correc, dummy_header_correc, dummy_meta, false, false);
         put_uint32_le(databuffer, dummy_header_correc.crc);
         databuffer += 4;
-        if (meta_correc.channel_count > 2) {
+        if (2 < meta_correc.channel_count) {
           // not stored for the last block
           put_uint32_le(databuffer, block_size);
           databuffer += 4;
@@ -235,8 +229,7 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
         databuffer += block_size;
       }
 
-      packet->data_adds.push_back(memory_cptr(new memory_c(chunk_correc,
-                                                           data_size, true)));
+      packet->data_adds.push_back(memory_cptr(new memory_c(chunk_correc, data_size, true)));
     }
   }
 
