@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: cluster_helper.cpp 3521 2007-03-22 09:06:14Z mosu $
+   $Id: cluster_helper.cpp 3775 2008-03-02 11:43:54Z mosu $
 
    The cluster helper groups frames into blocks groups and those
    into clusters, sets the durations, renders the clusters etc.
@@ -60,7 +60,6 @@ cluster_helper_c::~cluster_helper_c() {
 void
 cluster_helper_c::add_packet(packet_cptr packet) {
   int64_t timecode, timecode_delay, additional_size;
-  int i;
   bool split;
 
   if (!cluster)
@@ -106,7 +105,7 @@ cluster_helper_c::add_packet(packet_cptr packet) {
 
   if (splitting() &&
       (split_points.end() != current_split_point) &&
-      (file_num <= split_max_num_files) &&
+      (g_file_num <= split_max_num_files) &&
       (packet->bref == -1) &&
       ((packet->source->get_track_type() == track_video) ||
        (video_packetizer == NULL))) {
@@ -116,11 +115,12 @@ cluster_helper_c::add_packet(packet_cptr packet) {
     if (split_point_t::SPT_SIZE == current_split_point->m_type) {
 
       if (!packets.empty()) {
+        vector<packet_cptr>::iterator p_it;
         // Cluster + Cluster timecode (roughly)
         additional_size = 21;
         // Add sizes for all frames.
-        for (i = 0; i < packets.size(); i++) {
-          packet_cptr &p = packets[i];
+        for (p_it = packets.begin(); packets.end() != p_it; p_it++) {
+          packet_cptr &p = *p_it;
           additional_size += p->data->get_size();
           if (p->bref == -1)
             additional_size += 10;
@@ -296,8 +296,7 @@ cluster_helper_c::render() {
   kax_block_blob_c *new_block_group, *last_block_group;
   DataBuffer *data_buffer;
   int i, k, elements_in_cluster;
-  packet_cptr pack;
-  int64_t max_cl_timecode;
+  int64_t min_cl_timecode, max_cl_timecode;
   generic_packetizer_c *source;
   vector<render_groups_t *> render_groups;
   render_groups_t *render_group;
@@ -307,6 +306,7 @@ cluster_helper_c::render() {
   BlockBlobType this_block_blob_type, std_block_blob_type = use_simpleblock ?
     BLOCK_BLOB_ALWAYS_SIMPLE : BLOCK_BLOB_NO_SIMPLE;
 
+  min_cl_timecode = 9223372036854775807LL;
   max_cl_timecode = 0;
 
   // Splitpoint stuff
@@ -324,8 +324,14 @@ cluster_helper_c::render() {
   else
     lacing_type = LACING_AUTO;
 
-  for (i = 0; i < packets.size(); i++) {
-    pack = packets[i];
+  // Make sure that we don't have negative/wrapped around timecodes in the output file.
+  // Can happend when we're splitting; so adjust timecode_offset accordingly.
+  vector<packet_cptr>::iterator pack_it;
+  mxforeach(pack_it, packets)
+    timecode_offset = MXMIN(timecode_offset, (*pack_it)->assigned_timecode);
+
+  mxforeach(pack_it, packets) {
+    packet_cptr &pack = *pack_it;
     source = pack->source;
 
     has_codec_state = NULL != pack->codec_state.get();
@@ -347,9 +353,8 @@ cluster_helper_c::render() {
       render_groups.push_back(render_group);
     }
 
-    if (i == 0)
-      cluster->set_min_timecode(pack->assigned_timecode - timecode_offset);
-    max_cl_timecode = pack->assigned_timecode;
+    min_cl_timecode = MXMIN(pack->assigned_timecode, min_cl_timecode);
+    max_cl_timecode = MXMAX(pack->assigned_timecode, max_cl_timecode);
 
     data_buffer = new DataBuffer((binary *)pack->data->get(),
                                  pack->data->get_size());
@@ -485,7 +490,11 @@ cluster_helper_c::render() {
   if (elements_in_cluster > 0) {
     for (i = 0; i < render_groups.size(); i++)
       set_duration(render_groups[i]);
+
+    cluster->SetPreviousTimecode(min_cl_timecode - timecode_offset - 1, (int64_t)timecode_scale);
+    cluster->set_min_timecode(min_cl_timecode - timecode_offset);
     cluster->set_max_timecode(max_cl_timecode - timecode_offset);
+
     cluster->Render(*out, *kax_cues);
     bytes_in_file += cluster->ElementSize();
 
