@@ -8,7 +8,7 @@
    or visit http://www.gnu.org/copyleft/gpl.html
 
    \file
-   \version $Id: mkvmerge.cpp 3755 2008-02-26 19:08:38Z mosu $
+   \version $Id: mkvmerge.cpp 3869 2008-08-30 12:45:54Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
    \author Modified by Steve Lhomme <steve.lhomme@free.fr>.
@@ -16,9 +16,9 @@
 
 #include "os.h"
 
+#include <boost/regex.hpp>
 #include <errno.h>
 #include <ctype.h>
-#include <pcrecpp.h>
 #if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
 #include <signal.h>
 #endif
@@ -80,7 +80,7 @@ file_type_t file_types[] =
    {"mp2 ", FILE_TYPE_MP3, "MPEG-1 layer II audio (CBR and VBR/ABR)"},
    {"mp3 ", FILE_TYPE_MP3, "MPEG-1 layer III audio (CBR and VBR/ABR)"},
    {"mkv ", FILE_TYPE_MATROSKA, "general Matroska files"},
-   {"ogg ", FILE_TYPE_OGM, "audio/video embedded in OGG"},
+   {"ogg ", FILE_TYPE_OGM, "audio/video/text subtitles embedded in OGG"},
    {"mov ", FILE_TYPE_QTMP4, "Quicktime/MP4 audio and video"},
    {"rm  ", FILE_TYPE_REAL, "RealMedia audio and video"},
    {"srt ", FILE_TYPE_SRT, "SRT text subtitles"},
@@ -113,6 +113,7 @@ file_type_t file_types[] =
    {"    ", -1,      "VobSub subtitles"},
    {"    ", -1,      "Vorbis audio"},
    {"    ", -1,      "WAVPACK lossless audio"},
+   {"    ", -1,      "Kate subtitles"},
    {NULL,  -1,      NULL}};
 
 /** \brief Outputs usage information
@@ -197,18 +198,13 @@ set_usage() {
     "  --no-chapters            Don't keep chapters from a Matroska file.\n"
     "  --no-attachments         Don't keep attachments from a Matroska file.\n"
     "  --no-tags                Don't keep tags from a Matroska file.\n"
-    "  -y, --sync <TID:d[,o[/p]]>\n"
-    "                           Synchronize, delay the audio track with the\n"
-    "                           id TID by d ms. \n"
-    "                           d > 0: Pad with silent samples.\n"
-    "                           d < 0: Remove samples from the beginning.\n"
-    "                           o/p: Adjust the timecodes by o/p to fix\n"
-    "                           linear drifts. p defaults to 1000 if\n"
-    "                           omitted. Both o and p can be floating point\n"
-    "                           numbers.\n"
-    "  --delay <TID:Xs|ms|us|ns>\n"
-    "                           Delay to apply to the packets of the track\n"
-    "                           by simply adjusting the timecodes.\n"
+    "  -y, --sync, --delay <TID:d[,o[/p]]>\n"
+    "                           Synchronize, adjust the track's timecodes with\n"
+    "                           the id TID by 'd' ms.\n"
+    "                           'o/p': Adjust the timecodes by multiplying with\n"
+    "                           'o/p' to fix linear drifts. 'p' defaults to\n"
+    "                           1000 if omitted. Both 'o' and 'p' can be\n"
+    "                           floating point numbers.\n"
     "  --default-track <TID[:bool]>\n"
     "                           Sets the 'default' flag for this track or\n"
     "                           forces it not to be present if bool is 0.\n"
@@ -221,7 +217,8 @@ set_usage() {
     "  --language <TID:lang>    Sets the language for the track (ISO639-2\n"
     "                           code, see --list-languages).\n"
     "  -t, --tags <TID:file>    Read tags for the track from a XML file.\n"
-    "  --aac-is-sbr <TID>       Track with the ID is HE-AAC/AAC+/SBR-AAC.\n"
+    "  --aac-is-sbr <TID[:0|1]> The track with the ID is HE-AAC/AAC+/SBR-AAC\n"
+    "                           or not. The value ':1' can be omitted.\n"
     "  --timecodes <TID:file>   Read the timecodes to be used from a file.\n"
     "  --default-duration <TID:Xs|ms|us|ns|fps>\n"
     "                           Force the default duration of a track to X.\n"
@@ -359,14 +356,14 @@ identify(const string &filename) {
   track_info_c ti;
   filelist_t file;
 
-  file.name = filename;
-  get_file_type(file);
-  ti.fname = file.name;
+  verbose           = 0;
+  suppress_warnings = true;
+  identifying       = true;
+  file.name         = filename;
 
-  if (FILE_TYPE_MPEG_TS == file.type)
-    mxerror(_("The file '%s' has been detected as a MPEG transport stream. "
-              "This file format is not supported by mkvmerge.\n"),
-            file.name.c_str());
+  get_file_type(file);
+
+  ti.fname = file.name;
 
   if (file.type == FILE_TYPE_IS_UNKNOWN)
     mxerror(_("File %s has unknown type. Please have a look "
@@ -379,9 +376,6 @@ identify(const string &filename) {
 
   files.push_back(file);
 
-  verbose = 0;
-  identifying = true;
-  suppress_warnings = true;
   create_readers();
 
   files[0].reader->identify();
@@ -399,34 +393,36 @@ parse_number_with_unit(const string &s,
                        const string &subject,
                        const string &argument,
                        string display_s = "") {
-  pcrecpp::RE_Options opt_caseless;
-  opt_caseless.set_caseless(true);
-  pcrecpp::RE re1("(-?\\d+\\.?\\d*)(s|ms|us|ns|fps)?", opt_caseless);
-  pcrecpp::RE re2("(-?\\d+)/(-?\\d+)(s|ms|us|ns|fps)?", opt_caseless);
+  boost::regex re1("(-?\\d+\\.?\\d*)(s|ms|us|ns|fps)?", boost::regex::perl | boost::regbase::icase);
+  boost::regex re2("(-?\\d+)/(-?\\d+)(s|ms|us|ns|fps)?", boost::regex::perl | boost::regbase::icase);
+
   string unit, s_n, s_d;
-  int64_t n, d, multiplier;
+  int64_t n, d;
   double d_value = 0.0;
   bool is_fraction = false;
 
-  if (display_s == "")
+  if (display_s.empty())
     display_s = s;
 
-  if (re1.FullMatch(s, &s_n, &unit)) {
-    parse_double(s_n, d_value);
+  boost::match_results<std::string::const_iterator> matches;
+  if (boost::regex_match(s, matches, re1, boost::match_default)) {
+    parse_double(matches[1], d_value);
+    if (matches.size() > 2)
+      unit = matches[2];
     d = 1;
 
-  } else if (re2.FullMatch(s, &s_n, &s_d, &unit)) {
-    parse_int(s_n, n);
-    parse_int(s_d, d);
+  } else if (boost::regex_match(s, matches, re2, boost::match_default)) {
+    parse_int(matches[1], n);
+    parse_int(matches[2], d);
+    if (matches.size() > 3)
+      unit = matches[3];
     is_fraction = true;
 
   } else
-    mxerror(_("'%s' is not a valid %s in '%s %s'.\n"),
-            s.c_str(), subject.c_str(), argument.c_str(), display_s.c_str());
+    mxerror(_("'%s' is not a valid %s in '%s %s'.\n"), s.c_str(), subject.c_str(), argument.c_str(), display_s.c_str());
 
-  multiplier = 1000000000;
-
-  unit = downcase(unit);
+  int64_t multiplier = 1000000000;
+  unit               = downcase(unit);
 
   if (unit == "ms")
     multiplier = 1000000;
@@ -443,10 +439,9 @@ parse_number_with_unit(const string &s,
       return (int64_t)(1001000000.0 / 24.0);
     else
       return (int64_t)(1000000000.0 / d_value);
+
   } else if (unit != "s")
-    mxerror(_("'%s' does not contain a valid unit ('s', 'ms', 'us' or 'ns') "
-              "in '%s %s'.\n"), s.c_str(), argument.c_str(),
-            display_s.c_str());
+    mxerror(_("'%s' does not contain a valid unit ('s', 'ms', 'us' or 'ns') in '%s %s'.\n"), s.c_str(), argument.c_str(), display_s.c_str());
 
   if (is_fraction)
     return multiplier * n / d;
@@ -527,14 +522,15 @@ parse_tracks(string s,
 
    The argument must have the form <tt>TID:d</tt> or
    <tt>TID:d,l1/l2</tt>, e.g. <tt>0:200</tt>.  The part before the
-   comma is the displacement in ms. The optional part after comma is
-   the linear factor which defaults to 1 if not given.
+   comma is the displacement in ms.
+   The optional part after comma is the linear factor which defaults
+   to 1 if not given.
 */
 static void
 parse_sync(string s,
            const string &opt,
            track_info_c &ti) {
-  audio_sync_t async;
+  timecode_sync_t tcsync;
   vector<string> parts;
   string orig, linear, div;
   int idx;
@@ -545,18 +541,15 @@ parse_sync(string s,
   orig = s;
   parts = split(s, ":", 2);
   if (parts.size() != 2)
-    mxerror(_("Invalid sync option. No track ID specified in '%s %s'.\n"),
-            opt.c_str(), s.c_str());
+    mxerror(_("Invalid sync option. No track ID specified in '%s %s'.\n"), opt.c_str(), s.c_str());
 
   id = 0;
   if (!parse_int(parts[0], id))
-    mxerror(_("Invalid track ID specified in '%s %s'.\n"), opt.c_str(),
-            s.c_str());
+    mxerror(_("Invalid track ID specified in '%s %s'.\n"), opt.c_str(), s.c_str());
 
   s = parts[1];
   if (s.size() == 0)
-    mxerror(_("Invalid sync option specified in '%s %s'.\n"), opt.c_str(),
-            orig.c_str());
+    mxerror(_("Invalid sync option specified in '%s %s'.\n"), opt.c_str(), orig.c_str());
 
   // Now parse the actual sync values.
   idx = s.find(',');
@@ -564,29 +557,29 @@ parse_sync(string s,
     linear = s.substr(idx + 1);
     s.erase(idx);
     idx = linear.find('/');
-    if (idx < 0)
-      async.linear = strtod(linear.c_str(), NULL) / 1000.0;
-    else {
+    if (idx < 0) {
+      tcsync.numerator   = strtod(linear.c_str(), NULL);
+      tcsync.denominator = 1.0;
+
+    } else {
       div = linear.substr(idx + 1);
       linear.erase(idx);
       d1 = strtod(linear.c_str(), NULL);
       d2 = strtod(div.c_str(), NULL);
       if (d2 == 0.0)
-        mxerror(_("Invalid sync option specified in '%s %s'. The divisor is "
-                  "zero.\n"), opt.c_str(), orig.c_str());
+        mxerror(_("Invalid sync option specified in '%s %s'. The divisor is zero.\n"), opt.c_str(), orig.c_str());
 
-      async.linear = d1 / d2;
+      tcsync.numerator   = d1;
+      tcsync.denominator = d2;
     }
-    if (async.linear <= 0.0)
-      mxerror(_("Invalid sync option specified in '%s %s'. The linear sync "
-                "value may not be smaller than zero.\n"), opt.c_str(),
-              orig.c_str());
+    if ((tcsync.numerator * tcsync.denominator) <= 0.0)
+      mxerror(_("Invalid sync option specified in '%s %s'. The linear sync value may not be equal to or smaller than zero.\n"), opt.c_str(), orig.c_str());
 
-  } else
-    async.linear = 1.0;
-  async.displacement = atoi(s.c_str());
+  }
 
-  ti.audio_syncs[id] = async;
+  tcsync.displacement   = (int64_t)atoi(s.c_str()) * 1000000ll;
+
+  ti.timecode_syncs[id] = tcsync;
 }
 
 /** \brief Parse the \c --aspect-ratio argument
@@ -907,34 +900,6 @@ parse_split(const string &arg) {
   }
 }
 
-/** \brief Parse the \c --delay argument
-
-   time based: A number that must be postfixed with <tt>s</tt>,
-   <tt>ms</tt>, <tt>us</tt> or <tt>ns</tt> to specify seconds,
-   milliseconds, microseconds and nanoseconds respectively.
-*/
-static void
-parse_delay(const string &s,
-            track_info_c &ti) {
-  string unit;
-  vector<string> parts;
-  int64_t id;
-
-  // Extract the track number.
-  parts = split(s, ":", 2);
-  strip(parts);
-  if (parts.size() != 2)
-    mxerror(_("Invalid delay option. No track ID specified in "
-              "'--delay %s'.\n"), s.c_str());
-
-  id = 0;
-  if (!parse_int(parts[0], id))
-    mxerror(_("Invalid track ID specified in '--delay %s'.\n"), s.c_str());
-
-  ti.packet_delays[id] = parse_number_with_unit(parts[1], "delay", "--delay",
-                                                s);
-}
-
 /** \brief Parse the \c --default-track argument
 
    The argument must have the form \c TID or \c TID:boolean. The former
@@ -1608,7 +1573,7 @@ parse_args(vector<string> args) {
         mxerror(_("'%s' is not a valid priority class.\n"), next_arg.c_str());
       sit++;
 
-    } else if (this_arg == "-q")
+    } else if ((this_arg == "-q") || (this_arg == "--quiet"))
       verbose = 0;
 
     else if ((this_arg == "-v") || (this_arg == "--verbose"))
@@ -2010,7 +1975,7 @@ parse_args(vector<string> args) {
 
     } else if ((this_arg == "-y") || (this_arg == "--sync")) {
       if (no_next_arg)
-        mxerror(_("'%s' lacks the audio delay.\n"), this_arg.c_str());
+        mxerror(_("'%s' lacks the delay.\n"), this_arg.c_str());
 
       parse_sync(next_arg, this_arg, *ti);
       sit++;
@@ -2022,13 +1987,6 @@ parse_args(vector<string> args) {
       parse_cues(next_arg, *ti);
       sit++;
 
-    } else if (this_arg == "--delay") {
-      if (no_next_arg)
-        mxerror(_("'--delay' lacks the delay to apply.\n"));
-
-      parse_delay(next_arg, *ti);
-      sit++;
-
     } else if (this_arg == "--default-track") {
       if (no_next_arg)
         mxerror(_("'--default-track' lacks its argument.\n"));
