@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mkvmerge.h 3523 2007-04-18 17:20:18Z mosu $
+   $Id: mkvmerge.h 3827 2008-08-18 20:41:40Z mosu $
 
    definition of global variables found in mkvmerge.cpp
 
@@ -30,12 +30,14 @@ enum file_type_e {
   FILE_TYPE_IS_UNKNOWN = 0,
   FILE_TYPE_AAC,
   FILE_TYPE_AC3,
+  FILE_TYPE_ASF,
   FILE_TYPE_AVC_ES,
   FILE_TYPE_AVI,
   FILE_TYPE_CHAPTERS,
   FILE_TYPE_COREPICTURE,
   FILE_TYPE_DTS,
   FILE_TYPE_FLAC,
+  FILE_TYPE_FLV,
   FILE_TYPE_MATROSKA,
   FILE_TYPE_MICRODVD,
   FILE_TYPE_MP3,
