@@ -8,7 +8,7 @@
    or visit http://www.gnu.org/copyleft/gpl.html
 
    \file
-   \version $Id: output_control.cpp 3754 2008-02-25 17:13:13Z mosu $
+   \version $Id: output_control.cpp 3838 2008-08-21 15:04:24Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
    \author Modified by Steve Lhomme <steve.lhomme@free.fr>.
@@ -73,10 +73,12 @@
 #include "output_control.h"
 #include "r_aac.h"
 #include "r_ac3.h"
+#include "r_asf.h"
 #include "r_avc.h"
 #include "r_avi.h"
 #include "r_dts.h"
 #include "r_flac.h"
+#include "r_flv.h"
 #include "r_matroska.h"
 #include "r_mp3.h"
 #include "r_mpeg.h"
@@ -216,11 +218,6 @@ family_uids_c::add_family_uid(const KaxSegmentFamily &family) {
 #if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
 void
 sighandler(int signum) {
-#ifdef DEBUG
-  if (signum == SIGUSR1)
-    debug_facility.dump_info();
-#endif // DEBUG
-
   if (out == NULL)
     mxerror(_("mkvmerge was interrupted by a SIGINT (Ctrl+C?)\n"));
 
@@ -300,7 +297,13 @@ get_file_type(filelist_t &file) {
   }
 
   type = FILE_TYPE_IS_UNKNOWN;
-  if (avi_reader_c::probe_file(io, size))
+  // File types that can be detected unambiguously but are not supported
+  if (asf_reader_c::probe_file(io, size))
+    type = FILE_TYPE_ASF;
+  else if (flv_reader_c::probe_file(io, size))
+    type = FILE_TYPE_FLV;
+  // File types that can be detected unambiguously
+  else if (avi_reader_c::probe_file(io, size))
     type = FILE_TYPE_AVI;
   else if (kax_reader_c::probe_file(io, size))
     type = FILE_TYPE_MATROSKA;
@@ -318,17 +321,23 @@ get_file_type(filelist_t &file) {
     type = FILE_TYPE_TTA;
   else if (wavpack_reader_c::probe_file(io, size))
     type = FILE_TYPE_WAVPACK4;
+  // File types that are misdetected sometimes
   else if (mpeg_ts_reader_c::probe_file(io, size))
     type = FILE_TYPE_MPEG_TS;
   else if (mpeg_ps_reader_c::probe_file(io, size))
     type = FILE_TYPE_MPEG_PS;
+  else if (mpeg_es_reader_c::probe_file(io, size))
+    type = FILE_TYPE_MPEG_ES;
   else {
+    // File types which are the same in raw format and in other container formats.
+    // Detection requires five or more consecutive packets. 
     for (i = 0; (probe_sizes[i] != 0) && (type == FILE_TYPE_IS_UNKNOWN); i++)
       if (mp3_reader_c::probe_file(io, size, probe_sizes[i], 5))
         type = FILE_TYPE_MP3;
       else if (ac3_reader_c::probe_file(io, size, probe_sizes[i], 5))
         type = FILE_TYPE_AC3;
   }
+  // More file types with detection issues.
   if (type != FILE_TYPE_IS_UNKNOWN)
     ;
   else if (mp3_reader_c::probe_file(io, size, 2 * 1024 * 1024, 10))
@@ -339,11 +348,10 @@ get_file_type(filelist_t &file) {
     type = FILE_TYPE_AAC;
   else if (vobbtn_reader_c::probe_file(io, size))
     type = FILE_TYPE_VOBBTN;
-  else if (mpeg_es_reader_c::probe_file(io, size))
-    type = FILE_TYPE_MPEG_ES;
   else if (avc_es_reader_c::probe_file(io, size))
     type = FILE_TYPE_AVC_ES;
   else {
+    // All text file types (subtitles).
     try {
       text_io = new mm_text_io_c(new mm_file_io_c(file.name));
       text_io->setFilePointer(0, seek_end);
