@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: output_control.h 3579 2007-08-19 08:53:32Z mosu $
+   $Id: output_control.h 3754 2008-02-25 17:13:13Z mosu $
 
    output handling
 
@@ -178,7 +178,7 @@ extern bool no_lacing, no_linking, use_durations;
 
 extern bool identifying, identify_verbose;
 
-extern int file_num;
+extern int g_file_num;
 
 extern int64_t max_ns_per_cluster;
 extern int max_blocks_per_cluster;
