@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: pr_generic.h 3755 2008-02-26 19:08:38Z mosu $
+   $Id: pr_generic.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the generic reader and packetizer
 
@@ -95,11 +95,15 @@ enum file_status_e {
   FILE_STATUS_MOREDATA
 };
 
-struct audio_sync_t {
+struct timecode_sync_t {
   int64_t displacement;
-  double linear;
+  double numerator, denominator;
 
-  audio_sync_t(): displacement(0), linear(0.0) {}
+  timecode_sync_t(): displacement(0), numerator(1.0), denominator(1.0) {}
+
+  double factor() {
+    return numerator / denominator;
+  }
 };
 
 enum default_track_priority_e {
@@ -158,8 +162,8 @@ public:
   int display_width, display_height;
   bool aspect_ratio_given, aspect_ratio_is_factor, display_dimensions_given;
 
-  map<int64_t, audio_sync_t> audio_syncs; // As given on the command line
-  audio_sync_t async;           // For this very track
+  map<int64_t, timecode_sync_t> timecode_syncs; // As given on the command line
+  timecode_sync_t tcsync;                       // For this very track
 
   map<int64_t, cue_strategy_e> cue_creations; // As given on the command line
   cue_strategy_e cues;          // For this very track
@@ -181,9 +185,6 @@ public:
   map<int64_t, bool> all_aac_is_sbr;  // For AAC+/HE-AAC/SBR
   int aac_is_sbr;                     // For this track. -1 = unspecified
 
-  map<int64_t, int64_t> packet_delays; // As given on the command line
-  int64_t packet_delay;         // For this very track
-
   map<int64_t, compression_method_e> compression_list; // As given on the cmd line
   compression_method_e compression; // For this very track
 
@@ -296,6 +297,8 @@ protected:
   virtual void id_result_track(int64_t track_id, const string &type, const string &info, const string &verbose_info = empty_string);
   virtual void id_result_track(int64_t track_id, const string &type, const string &info, const vector<string> &verbose_info);
   virtual void id_result_attachment(int64_t attachment_id, const string &type, int size, const string &file_name = empty_string, const string &description = empty_string);
+
+  static void id_result_container_unsupported(const string &filename, const string &info);
 };
 
 enum connection_result_e {
@@ -363,7 +366,6 @@ protected:
   deque<packet_cptr> packet_queue, deferred_packets;
   int next_packet_wo_assigned_timecode;
 
-  int64_t initial_displacement;
   int64_t m_free_refs, m_next_free_refs, enqueued_bytes;
   int64_t safety_last_timecode, safety_last_duration;
 
@@ -450,8 +452,6 @@ public:
   }
   virtual int process(packet_cptr packet) = 0;
 
-  virtual void dump_debug_info() = 0;
-
   virtual void set_cue_creation(cue_strategy_e create_cue_data) {
     ti.cues = create_cue_data;
   }
@@ -525,17 +525,6 @@ public:
     hcompression = method;
   }
 
-  inline bool needs_negative_displacement(float) {
-    return ((initial_displacement < 0) &&
-            (ti.async.displacement > initial_displacement));
-  }
-  inline bool needs_positive_displacement(float duration) {
-    return ((initial_displacement > 0) &&
-            (iabs(ti.async.displacement - initial_displacement) >
-             (duration / 2)));
-  }
-  virtual void displace(float by_ns);
-
   virtual void force_duration_on_last_packet();
 
   virtual const char *get_format_name() = 0;
