@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_aac.cpp 3024 2005-08-17 11:46:09Z mosu $
+   $Id: p_aac.cpp 3838 2008-08-21 15:04:24Z mosu $
 
    AAC output module
 
@@ -18,10 +18,10 @@
 #include <string.h>
 #include <errno.h>
 
-#include "pr_generic.h"
 #include "aac_common.h"
-#include "p_aac.h"
+#include "hacks.h"
 #include "matroska.h"
+#include "p_aac.h"
 
 using namespace libmatroska;
 
@@ -35,14 +35,14 @@ aac_packetizer_c::aac_packetizer_c(generic_reader_c *_reader,
                                    bool _headerless)
   throw (error_c):
   generic_packetizer_c(_reader, _ti),
-  bytes_output(0), packetno(0), last_timecode(-1), num_packets_same_tc(0), 
+  bytes_output(0), packetno(0), last_timecode(-1), num_packets_same_tc(0),
+  bytes_skipped(0),
   samples_per_sec(_samples_per_sec), channels(_channels), id(_id),
   profile(_profile), headerless(_headerless),
   emphasis_present(_emphasis_present) {
 
   set_track_type(track_audio);
-  set_track_default_duration((int64_t)(1024 * 1000000000.0 * ti.async.linear /
-                                       samples_per_sec));
+  set_track_default_duration((int64_t)(1024 * 1000000000.0 / samples_per_sec));
 }
 
 aac_packetizer_c::~aac_packetizer_c() {
@@ -53,33 +53,28 @@ aac_packetizer_c::get_aac_packet(unsigned long *header,
                                  aac_header_t *aacheader) {
   int pos, i, up_shift, down_shift, size;
   unsigned char *buf, *src, *packet_buffer;
-  double pins;
 
   packet_buffer = byte_buffer.get_buffer();
   size = byte_buffer.get_size();
   pos = find_aac_header(packet_buffer, size, aacheader, emphasis_present);
-  if (pos < 0)
+  if (pos < 0) {
+    if (10 < size) {
+      bytes_skipped += size - 10;
+      byte_buffer.remove(size - 10);
+    }
     return NULL;
+  }
   if ((pos + aacheader->bytes) > size)
     return NULL;
 
-  pins = 1024 * 1000000000.0 / samples_per_sec;
-
-  if (needs_negative_displacement(pins)) {
-    /*
-     * AAC audio synchronization. displacement < 0 means skipping an
-     * appropriate number of packets at the beginning.
-     */
-    displace(-pins);
-    byte_buffer.remove(pos + aacheader->bytes);
-
-    return get_aac_packet(header, aacheader);
-  }
-
-  if (verbose && (pos > 0))
-    mxwarn("aac_packetizer: skipping %d bytes (no valid AAC header "
+  bytes_skipped += pos;
+  if (verbose && (0 < bytes_skipped))
+    mxwarn(FMT_TID "skipping " LLD " bytes (no valid AAC header "
            "found). This might make audio/video go out of sync, but this "
-           "stream is damaged.\n", pos);
+           "stream is damaged.\n", ti.fname.c_str(), (int64_t)0,
+           bytes_skipped);
+  bytes_skipped = 0;
+
   if ((aacheader->header_bit_size % 8) == 0)
     buf = (unsigned char *)safememdup(packet_buffer + pos +
                                       aacheader->header_byte_size,
@@ -100,19 +95,6 @@ aac_packetizer_c::get_aac_packet(unsigned long *header,
     }
   }
 
-  if (needs_positive_displacement(pins)) {
-    /*
-     * AAC audio synchronization. displacement > 0 is solved by duplicating
-     * the very first AAC packet as often as necessary. I cannot create
-     * a packet with total silence because I don't know how, and simply
-     * settings the packet's values to 0 does not work as the AAC header
-     * contains a CRC of its data.
-     */
-    displace(pins);
-
-    return buf;
-  }
-
   byte_buffer.remove(pos + aacheader->bytes);
 
   return buf;
@@ -120,7 +102,9 @@ aac_packetizer_c::get_aac_packet(unsigned long *header,
 
 void
 aac_packetizer_c::set_headers() {
-  if (id == AAC_ID_MPEG4) {
+  if (!hack_engaged(ENGAGE_OLD_AAC_CODECID))
+    set_codec_id(MKV_A_AAC);
+  else if (id == AAC_ID_MPEG4) {
     if (profile == AAC_PROFILE_MAIN)
       set_codec_id(MKV_A_AAC_4MAIN);
     else if (profile == AAC_PROFILE_LC)
@@ -148,88 +132,66 @@ aac_packetizer_c::set_headers() {
   set_audio_sampling_freq((float)samples_per_sec);
   set_audio_channels(channels);
 
-  if ((ti.private_data != NULL) && (ti.private_size > 0) &&
-      (ti.private_size != 2) && (ti.private_size != 5))
+  if ((ti.private_data != NULL) && (ti.private_size > 0))
     set_codec_private(ti.private_data, ti.private_size);
+  else if (!hack_engaged(ENGAGE_OLD_AAC_CODECID)) {
+    unsigned char buffer[5];
+    int length;
+
+    length = create_aac_data(buffer, profile == AAC_PROFILE_SBR ?
+                             AAC_PROFILE_LC : profile,
+                             channels, samples_per_sec,
+                             profile == AAC_PROFILE_SBR ? samples_per_sec * 2 :
+                             samples_per_sec,
+                             profile == AAC_PROFILE_SBR);
+    set_codec_private(buffer, length);
+  }
 
   generic_packetizer_c::set_headers();
 }
 
 int
-aac_packetizer_c::process(packet_cptr packet) {
-  unsigned char *aac_packet;
-  unsigned long header;
-  aac_header_t aacheader;
-  int64_t my_timecode, duration, timecode;
+aac_packetizer_c::process_headerless(packet_cptr packet) {
+  int64_t new_timecode;
 
-  debug_enter("aac_packetizer_c::process");
-
-  timecode = packet->timecode;
-  my_timecode = 0;
-  if (headerless) {
-    if (timecode != -1) {
-      my_timecode = timecode;
-      if (last_timecode == timecode) {
-        num_packets_same_tc++;
-        my_timecode +=
-          (int64_t)(num_packets_same_tc * 1024 * 1000000000.0 /
-                    samples_per_sec);
-      } else {
-        last_timecode = timecode;
-        num_packets_same_tc = 0;
-      }
-    } else
-      my_timecode = (int64_t)(1024 * 1000000000.0 * packetno /
-                              samples_per_sec);
-    duration = (int64_t)(1024 * 1000000000.0 * ti.async.linear /
-                         samples_per_sec);
-    packetno++;
-
-    if (needs_negative_displacement(duration)) {
-      displace(-duration);
-      return FILE_STATUS_MOREDATA;
-    }
-    while (needs_positive_displacement(duration)) {
-      add_packet(new packet_t(packet->memory->clone(), my_timecode +
-                              ti.async.displacement, duration));
-      displace(duration);
+  if (packet->timecode != -1) {
+    new_timecode = packet->timecode;
+    if (last_timecode == packet->timecode) {
+      num_packets_same_tc++;
+      new_timecode += (int64_t)(num_packets_same_tc * 1024 * 1000000000.0 / samples_per_sec);
+    } else {
+      last_timecode = packet->timecode;
+      num_packets_same_tc = 0;
     }
+  } else
+    new_timecode = (int64_t)(1024 * 1000000000.0 * packetno / samples_per_sec);
 
-    packet->duration = duration;
-    packet->timecode = (int64_t)((my_timecode + ti.async.displacement) *
-                                 ti.async.linear);
-    mxverb(2, "aac: my_tc = %lld\n", packet->timecode);
-    add_packet(packet);
+  packetno++;
+  packet->duration = (int64_t)(1024 * 1000000000.0 / samples_per_sec);
+  packet->timecode = new_timecode;
 
-    debug_leave("aac_packetizer_c::process");
-
-    return FILE_STATUS_MOREDATA;
-  }
-
-  byte_buffer.add(packet->memory->data, packet->memory->size);
-  while ((aac_packet = get_aac_packet(&header, &aacheader)) != NULL) {
-    if (timecode == -1)
-      my_timecode = (int64_t)(1024 * 1000000000.0 * packetno /
-                              samples_per_sec);
-    else
-      my_timecode = timecode + ti.async.displacement;
-    add_packet(new packet_t(new memory_c(aac_packet,
-                                         aacheader.data_byte_size, true),
-                            (int64_t)(my_timecode * ti.async.linear),
-                            (int64_t)(1024 * 1000000000.0 * ti.async.linear /
-                                      samples_per_sec)));
-    packetno++;
-  }
-
-  debug_leave("aac_packetizer_c::process");
+  add_packet(packet);
 
   return FILE_STATUS_MOREDATA;
 }
 
-void
-aac_packetizer_c::dump_debug_info() {
-  mxdebug("aac_packetizer_c: queue: %u; buffer size: %d\n",
-          (unsigned int)packet_queue.size(), byte_buffer.get_size());
+int
+aac_packetizer_c::process(packet_cptr packet) {
+  if (headerless)
+    return process_headerless(packet);
+
+  unsigned char *aac_packet;
+  unsigned long header;
+  aac_header_t aacheader;
+
+  byte_buffer.add(packet->data->get(), packet->data->get_size());
+  while ((aac_packet = get_aac_packet(&header, &aacheader)) != NULL) {
+    int64_t my_timecode = -1 == packet->timecode ? (int64_t)(1024 * 1000000000.0 * packetno / samples_per_sec) : packet->timecode;
+    add_packet(new packet_t(new memory_c(aac_packet, aacheader.data_byte_size, true), my_timecode, (int64_t)(1024 * 1000000000.0 / samples_per_sec)));
+    packetno++;
+  }
+
+  return FILE_STATUS_MOREDATA;
 }
 
 connection_result_e
@@ -250,4 +212,3 @@ aac_packetizer_c::can_connect_to(generic_packetizer_c *src,
   }
   return CAN_CONNECT_YES;
 }
-
