@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_aac.h 2932 2005-05-25 21:31:26Z mosu $
+   $Id: p_aac.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the AAC output module
 
@@ -26,6 +26,7 @@
 class aac_packetizer_c: public generic_packetizer_c {
 private:
   int64_t bytes_output, packetno, last_timecode, num_packets_same_tc;
+  int64_t bytes_skipped;
   int samples_per_sec, channels, id, profile;
   bool headerless, emphasis_present;
   byte_buffer_c byte_buffer;
@@ -49,8 +50,7 @@ public:
 private:
   virtual unsigned char *get_aac_packet(unsigned long *header,
                                         aac_header_t *aacheader);
-
-  virtual void dump_debug_info();
+  virtual int process_headerless(packet_cptr packet);
 };
 
 #endif // __P_AAC_H
