@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_dts.h 2842 2005-03-02 15:53:34Z mosu $
+   $Id: p_dts.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the DTS output module
 
@@ -42,9 +42,7 @@ public:
     throw (error_c);
   virtual ~dts_packetizer_c();
 
-  virtual int process(memory_c &mem, int64_t timecode = -1,
-                      int64_t length = -1, int64_t bref = -1,
-                      int64_t fref = -1);
+  virtual int process(packet_cptr packet);
   virtual void set_headers();
   virtual const char *get_format_name() {
     return "DTS";
@@ -57,8 +55,6 @@ private:
   virtual unsigned char *get_dts_packet(dts_header_t &dts_header);
   virtual int dts_packet_available();
   virtual void remove_dts_packet(int pos, int framesize);
-
-  virtual void dump_debug_info();
 };
 
 #endif // __P_DTS_H
