@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_flac.cpp 3746 2008-02-19 16:29:34Z mosu $
+   $Id: p_flac.cpp 3838 2008-08-21 15:04:24Z mosu $
 
    FLAC packetizer
 
@@ -64,14 +64,7 @@ flac_packetizer_c::flac_packetizer_c(generic_reader_c *_reader,
 
   set_track_type(track_audio);
   if (stream_info.min_blocksize == stream_info.max_blocksize)
-    set_track_default_duration((int64_t)(1000000000ll *
-                                         stream_info.min_blocksize *
-                                         ti.async.linear /
-                                         stream_info.sample_rate));
-
-  if ((ti.async.displacement != 0) || (ti.async.linear != 1.0))
-    mxwarn("FLAC packetizer: Audio synchronization has not been "
-           "implemented for FLAC yet.\n");
+    set_track_default_duration((int64_t)(1000000000ll * stream_info.min_blocksize / stream_info.sample_rate));
 }
 
 flac_packetizer_c::~flac_packetizer_c() {
@@ -90,8 +83,6 @@ flac_packetizer_c::set_headers() {
 
 int
 flac_packetizer_c::process(packet_cptr packet) {
-  debug_enter("flac_packetizer_c::process");
-
   packet->duration =
     flac_get_num_samples(packet->data->get(), packet->data->get_size(),
                          stream_info);
@@ -99,22 +90,15 @@ flac_packetizer_c::process(packet_cptr packet) {
     mxwarn(_(FMT_TID "Packet number " LLD " contained an invalid FLAC header "
              "and is being skipped.\n"), ti.fname.c_str(), (int64_t)ti.id,
            num_packets + 1);
-    debug_leave("flac_packetizer_c::process");
     return FILE_STATUS_MOREDATA;
   }
   packet->duration = packet->duration * 1000000000ll / stream_info.sample_rate;
   add_packet(packet);
   num_packets++;
-  debug_leave("flac_packetizer_c::process");
 
   return FILE_STATUS_MOREDATA;
 }
 
-void
-flac_packetizer_c::dump_debug_info() {
-  mxdebug("flac_packetizer_c: queue: %u\n", (unsigned int)packet_queue.size());
-}
-
 connection_result_e
 flac_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                   string &error_message) {
