@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_flac.h 2932 2005-05-25 21:31:26Z mosu $
+   $Id: p_flac.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the Flac packetizer
 
@@ -30,8 +30,7 @@
 
 class flac_packetizer_c: public generic_packetizer_c {
 private:
-  autofree_ptr<unsigned char> header;
-  int l_header;
+  memory_cptr header;
   int64_t num_packets;
   FLAC__StreamMetadata_StreamInfo stream_info;
 
@@ -44,8 +43,6 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual void dump_debug_info();
-
   virtual const char *get_format_name() {
     return "Flac";
   }
