@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_mp3.cpp 3024 2005-08-17 11:46:09Z mosu $
+   $Id: p_mp3.cpp 3872 2008-09-06 14:50:38Z mosu $
 
    MP3 output module
 
@@ -32,13 +32,14 @@ mp3_packetizer_c::mp3_packetizer_c(generic_reader_c *_reader,
                                    track_info_c &_ti)
   throw (error_c):
   generic_packetizer_c(_reader, _ti), bytes_output(0), packetno(0),
+  bytes_skipped(0),
   samples_per_sec(_samples_per_sec), channels(_channels), spf(1152),
   byte_buffer(128 * 1024),
-  codec_id_set(false), valid_headers_found(source_is_good) {
+  codec_id_set(false), valid_headers_found(source_is_good),
+  previous_timecode(-1), num_packets_with_same_timecode(0) {
 
   set_track_type(track_audio);
-  set_track_default_duration((int64_t)(1152000000000.0 * ti.async.linear /
-                                       samples_per_sec));
+  set_track_default_duration((int64_t)(1152000000000.0 / samples_per_sec));
   enable_avi_audio_sync(true);
 }
 
@@ -56,16 +57,16 @@ mp3_packetizer_c::handle_garbage(int64_t bytes) {
     offset = handle_avi_audio_sync(bytes, !(ti.avi_block_align % 384) ||
                                    !(ti.avi_block_align % 576));
     if (offset != -1) {
-      mxinfo("The MPEG audio track %lld from '%s' contained %lld bytes of "
-             "garbage at the beginning. This corresponds to a delay of "
-             "%lldms. This delay will be used instead of the garbage data."
+      mxinfo("The MPEG audio track " LLD " from '%s' contained " LLD " bytes "
+             "of non-MP3 data at the beginning. This corresponds to a delay of"
+             " " LLD "ms. This delay will be used instead of the garbage data."
              "\n", ti.id, ti.fname.c_str(), bytes, offset / 1000000);
       warning_printed = true;
     }
   }
   if (!warning_printed)
-    mxwarn("The MPEG audio track %lld from '%s' contained %lld bytes of "
-           "garbage at the beginning which were skipped. The audio/video "
+    mxwarn("The MPEG audio track " LLD " from '%s' contained " LLD " bytes of "
+           "non-MP3 data which were skipped. The audio/video "
            "synchronization may have been lost.\n", ti.id, ti.fname.c_str(),
            bytes);
 }
@@ -74,7 +75,6 @@ unsigned char *
 mp3_packetizer_c::get_mp3_packet(mp3_header_t *mp3header) {
   int pos, size;
   unsigned char *buf;
-  double pins;
   string codec_id;
 
   if (byte_buffer.get_size() == 0)
@@ -108,21 +108,23 @@ mp3_packetizer_c::get_mp3_packet(mp3_header_t *mp3header) {
       // Great, we have found five consecutive identical headers. Be happy
       // with those!
       valid_headers_found = true;
-      if (pos > 0) {
-        handle_garbage(pos);
-        byte_buffer.remove(pos);
-      }
+      bytes_skipped += pos;
+      if (0 < bytes_skipped)
+        handle_garbage(bytes_skipped);
+      byte_buffer.remove(pos);
       pos = 0;
+      bytes_skipped = 0;
       decode_mp3_header(byte_buffer.get_buffer(), mp3header);
     } else
       return NULL;
   }
 
-  if (pos > 0) {
-    handle_garbage(pos);
-    byte_buffer.remove(pos);
-    pos = 0;
-  }
+  bytes_skipped += pos;
+  if (bytes_skipped > 0)
+    handle_garbage(bytes_skipped);
+  byte_buffer.remove(pos);
+  pos = 0;
+  bytes_skipped = 0;
 
   if (packetno == 0) {
     spf = mp3header->samples_per_channel;
@@ -130,43 +132,14 @@ mp3_packetizer_c::get_mp3_packet(mp3_header_t *mp3header) {
     codec_id[codec_id.length() - 1] = (char)(mp3header->layer + '0');
     set_codec_id(codec_id.c_str());
     if (spf != 1152)
-      set_track_default_duration((int64_t)(1000000000.0 * spf *
-                                           ti.async.linear /
-                                           samples_per_sec));
+      set_track_default_duration((int64_t)(1000000000.0 * spf / samples_per_sec));
     rerender_track_headers();
   }
 
   if (mp3header->framesize > byte_buffer.get_size())
     return NULL;
 
-  pins = 1000000000.0 * (double)spf / mp3header->sampling_frequency;
-
-  if (needs_negative_displacement(pins)) {
-    /*
-     * MP3 audio synchronization. displacement < 0 means skipping an
-     * appropriate number of packets at the beginning.
-     */
-    displace(-pins);
-    byte_buffer.remove(mp3header->framesize);
-
-    return get_mp3_packet(mp3header);
-  }
-
-  buf = (unsigned char *)safememdup(byte_buffer.get_buffer(),
-                                    mp3header->framesize);
-
-  if (needs_positive_displacement(pins)) {
-    /*
-     * MP3 audio synchronization. displacement > 0 is solved by creating
-     * silent MP3 packets and repeating it over and over again (well only as
-     * often as necessary of course. Wouldn't want to spoil your movie by
-     * providing a silent MP3 stream ;)).
-     */
-    displace(pins);
-    memset(buf + 4, 0, mp3header->framesize - 4);
-
-    return buf;
-  }
+  buf = (unsigned char *)safememdup(byte_buffer.get_buffer(), mp3header->framesize);
 
   byte_buffer.remove(mp3header->framesize);
 
@@ -189,35 +162,31 @@ int
 mp3_packetizer_c::process(packet_cptr packet) {
   unsigned char *mp3_packet;
   mp3_header_t mp3header;
-  int64_t my_timecode;
 
-  debug_enter("mp3_packetizer_c::process");
-
-  byte_buffer.add(packet->memory->data, packet->memory->size);
+  byte_buffer.add(packet->data->get(), packet->data->get_size());
   while ((mp3_packet = get_mp3_packet(&mp3header)) != NULL) {
-    if (packet->timecode == -1)
-      my_timecode = (int64_t)(1000000000.0 * packetno * spf / samples_per_sec);
-    else
-      my_timecode = packet->timecode + ti.async.displacement;
-    add_packet(new packet_t(new memory_c(mp3_packet, mp3header.framesize,
-                                         true),
-                            (int64_t)(my_timecode * ti.async.linear),
-                            (int64_t)(1000000000.0 * spf * ti.async.linear /
-                                      samples_per_sec)));
+    int64_t new_timecode;
+    if (-1 == packet->timecode)
+      new_timecode = (int64_t)(1000000000.0 * packetno * spf / samples_per_sec);
+    else {
+      if ((-1 != previous_timecode) && (packet->timecode == previous_timecode)) {
+        new_timecode = previous_timecode + num_packets_with_same_timecode * 1000000000ll * spf / samples_per_sec;
+        ++num_packets_with_same_timecode;
+      } else {
+        new_timecode                   = packet->timecode;
+        num_packets_with_same_timecode = 0;
+      }
+
+      previous_timecode = packet->timecode;
+    }
+
+    add_packet(new packet_t(new memory_c(mp3_packet, mp3header.framesize, true), new_timecode, (int64_t)(1000000000.0 * spf / samples_per_sec)));
     packetno++;
   }
 
-  debug_leave("mp3_packetizer_c::process");
-
   return FILE_STATUS_MOREDATA;
 }
 
-void
-mp3_packetizer_c::dump_debug_info() {
-  mxdebug("mp3_packetizer_c: queue: %u; buffer_size: %d\n",
-          (unsigned int)packet_queue.size(), byte_buffer.get_size());
-}
-
 connection_result_e
 mp3_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                  string &error_message) {
