@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_mp3.h 2842 2005-03-02 15:53:34Z mosu $
+   $Id: p_mp3.h 3872 2008-09-06 14:50:38Z mosu $
 
    class definition for the MP3 output module
 
@@ -25,32 +25,27 @@
 
 class mp3_packetizer_c: public generic_packetizer_c {
 private:
-  int64_t bytes_output, packetno;
+  int64_t bytes_output, packetno, bytes_skipped;
   int samples_per_sec, channels, spf;
   byte_buffer_c byte_buffer;
   bool codec_id_set, valid_headers_found;
+  int64_t previous_timecode, num_packets_with_same_timecode;
 
 public:
-  mp3_packetizer_c(generic_reader_c *_reader, int _samples_per_sec,
-                   int _channels, bool source_is_good, track_info_c &_ti)
-    throw (error_c);
+  mp3_packetizer_c(generic_reader_c *_reader, int _samples_per_sec, int _channels, bool source_is_good, track_info_c &_ti) throw (error_c);
   virtual ~mp3_packetizer_c();
 
-  virtual int process(memory_c &mem, int64_t timecode = -1,
-                      int64_t length = -1, int64_t bref = -1,
-                      int64_t fref = -1);
+  virtual int process(packet_cptr packet);
   virtual void set_headers();
 
   virtual const char *get_format_name() {
     return "MP3";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
-                                             string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
 
 private:
   virtual unsigned char *get_mp3_packet(mp3_header_t *mp3header);
 
-  virtual void dump_debug_info();
   virtual void handle_garbage(int64_t bytes);
 };
 
