@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_passthrough.h 2842 2005-03-02 15:53:34Z mosu $
+   $Id: p_passthrough.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the pass through output module
 
@@ -24,22 +24,13 @@
 class passthrough_packetizer_c: public generic_packetizer_c {
 private:
   int64_t packets_processed, bytes_processed;
-  bool sync_to_keyframe, sync_complete_group;
 
 public:
   passthrough_packetizer_c(generic_reader_c *_reader, track_info_c &_ti)
     throw (error_c);
 
-  virtual int process(memory_c &mem, int64_t timecode = -1,
-                      int64_t duration = -1, int64_t bref = -1,
-                      int64_t fref = -1);
-  virtual int process(memory_c &mem, int64_t timecode,
-                      int64_t duration, int64_t bref, int64_t fref,
-                      bool duration_mandatory);
+  virtual int process(packet_cptr packet);
   virtual void set_headers();
-  virtual void always_sync_complete_group(bool sync);
-
-  virtual void dump_debug_info();
 
   virtual const char *get_format_name() {
     return "passthrough";
