@@ -6,11 +6,12 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_pcm.cpp 3024 2005-08-17 11:46:09Z mosu $
+   $Id: p_pcm.cpp 3840 2008-08-23 12:02:10Z mosu $
 
    PCM output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
+   Patches by Robert Millan <rmh@aybabtu.com>.
 */
 
 #include <stdlib.h>
@@ -30,13 +31,14 @@ pcm_packetizer_c::pcm_packetizer_c(generic_reader_c *_reader,
                                    int _channels,
                                    int _bits_per_sample,
                                    track_info_c &_ti,
-                                   bool _big_endian)
+                                   bool _big_endian,
+                                   bool _float)
   throw (error_c):
   generic_packetizer_c(_reader, _ti),
   packetno(0), bps(_channels * _bits_per_sample * _samples_per_sec / 8),
   samples_per_sec(_samples_per_sec), channels(_channels),
   bits_per_sample(_bits_per_sample), packet_size(0),
-  bytes_output(0), skip_bytes(0), big_endian(_big_endian) {
+  bytes_output(0), big_endian(_big_endian), ieee_float(_float) {
 
   int i;
 
@@ -48,10 +50,12 @@ pcm_packetizer_c::pcm_packetizer_c(generic_reader_c *_reader,
   packet_size = samples_per_sec / i;
 
   set_track_type(track_audio);
-  set_track_default_duration((int64_t)(1000000000.0 * ti.async.linear *
-                                       packet_size / samples_per_sec));
+  set_track_default_duration((int64_t)(1000000000.0 * packet_size / samples_per_sec));
 
-  packet_size *= channels * bits_per_sample / 8;
+  /* It could happen that (channels * bits_per_sample < 8).  Because of this,
+     we mustn't divide by 8 in the same line, or the result would be hosed. */
+  packet_size *= channels * bits_per_sample;
+  packet_size /= 8;
 }
 
 pcm_packetizer_c::~pcm_packetizer_c() {
@@ -59,7 +63,9 @@ pcm_packetizer_c::~pcm_packetizer_c() {
 
 void
 pcm_packetizer_c::set_headers() {
-  if (big_endian)
+  if (ieee_float)
+    set_codec_id(MKV_A_PCM_FLOAT);
+  else if (big_endian)
     set_codec_id(MKV_A_PCM_BE);
   else
     set_codec_id(MKV_A_PCM);
@@ -72,51 +78,14 @@ pcm_packetizer_c::set_headers() {
 
 int
 pcm_packetizer_c::process(packet_cptr packet) {
-  unsigned char *new_buf;
-
-  debug_enter("pcm_packetizer_c::process");
-
-  if (initial_displacement != 0) {
-    if (initial_displacement > 0) {
-      // Add silence.
-      int64_t pad_size;
-
-      pad_size = (int64_t)bps * (int64_t)initial_displacement / 1000000000ll;
-      new_buf = (unsigned char *)safemalloc(pad_size);
-      memset(new_buf, 0, pad_size);
-      buffer.add(new_buf, pad_size);
-      safefree(new_buf);
-    } else
-      // Skip bytes.
-      skip_bytes = -1 * (int64_t)bps * (int64_t)initial_displacement /
-        1000000000ll;
-    initial_displacement = 0;
-  }
-
-  if (skip_bytes) {
-    if (skip_bytes > packet->memory->size) {
-      skip_bytes -= packet->memory->size;
-      return FILE_STATUS_MOREDATA;
-    }
-    packet->memory->size -= skip_bytes;
-    new_buf = &packet->memory->data[skip_bytes];
-    skip_bytes = 0;
-  } else
-    new_buf = packet->memory->data;
-
-  buffer.add(new_buf, packet->memory->size);
+  buffer.add(packet->data->get(), packet->data->get_size());
 
   while (buffer.get_size() >= packet_size) {
-    add_packet(new packet_t(new memory_c(buffer.get_buffer(), packet_size,
-                                         false),
-                            (int64_t)bytes_output * 1000000000ll / bps,
-                            (int64_t)packet_size * 1000000000ll / bps));
+    add_packet(new packet_t(new memory_c(buffer.get_buffer(), packet_size, false), (int64_t)bytes_output * 1000000000ll / bps, (int64_t)packet_size * 1000000000ll / bps));
     buffer.remove(packet_size);
     bytes_output += packet_size;
   }
 
-  debug_leave("pcm_packetizer_c::process");
-
   return FILE_STATUS_MOREDATA;
 }
 
@@ -136,11 +105,6 @@ pcm_packetizer_c::flush() {
   generic_packetizer_c::flush();
 }
 
-void
-pcm_packetizer_c::dump_debug_info() {
-  mxdebug("pcm_packetizer_c: queue: %u\n", (unsigned int)packet_queue.size());
-}
-
 connection_result_e
 pcm_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                  string &error_message) {
