@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_pcm.h 2842 2005-03-02 15:53:34Z mosu $
+   $Id: p_pcm.h 3840 2008-08-23 12:02:10Z mosu $
 
    class definition for the PCM output module
 
@@ -25,25 +25,21 @@
 class pcm_packetizer_c: public generic_packetizer_c {
 private:
   int packetno, bps, samples_per_sec, channels, bits_per_sample, packet_size;
-  int64_t bytes_output, skip_bytes;
-  bool big_endian;
+  int64_t bytes_output;
+  bool big_endian, ieee_float;
   byte_buffer_c buffer;
 
 public:
   pcm_packetizer_c(generic_reader_c *_reader, int _samples_per_sec,
                    int _channels, int _bits_per_sample, track_info_c &_ti,
-                   bool _big_endian = false)
+                   bool _big_endian = false, bool _float = false)
     throw (error_c);
   virtual ~pcm_packetizer_c();
 
-  virtual int process(memory_c &mem, int64_t timecode = -1,
-                      int64_t length = -1, int64_t bref = -1,
-                      int64_t fref = -1);
+  virtual int process(packet_cptr packet);
   virtual void set_headers();
   virtual void flush();
 
-  virtual void dump_debug_info();
-
   virtual const char *get_format_name() {
     return "PCM";
   }
