@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_realaudio.h 2932 2005-05-25 21:31:26Z mosu $
+   $Id: p_realaudio.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the RealAudio output module
 
@@ -27,8 +27,7 @@ private:
   int64_t bytes_output, packetno;
   int samples_per_sec, channels, bits_per_sample;
   uint32_t fourcc;
-  autofree_ptr<unsigned char> private_data;
-  int private_size;
+  memory_cptr private_data;
   bool skip_to_keyframe, buffer_until_keyframe;
   vector<memory_c *> buffered_packets;
   vector<int64_t> buffered_timecodes, buffered_durations;
@@ -49,9 +48,6 @@ public:
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src,
                                              string &error_message);
-
-protected:
-  virtual void dump_debug_info();
 };
 
 #endif // __P_REALAUDIO_H
