@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_textsubs.cpp 3024 2005-08-17 11:46:09Z mosu $
+   $Id: p_textsubs.cpp 3838 2008-08-21 15:04:24Z mosu $
 
    Subripper subtitle reader
 
@@ -34,8 +34,11 @@ textsubs_packetizer_c::textsubs_packetizer_c(generic_reader_c *_reader,
                                              track_info_c &_ti)
   throw (error_c):
   generic_packetizer_c(_reader, _ti),
-  packetno(0), cc_utf8(0), global_data(safememdup(_global_data, _global_size)),
-  global_size(_global_size), codec_id(_codec_id), recode(_recode) {
+  packetno(0), cc_utf8(0),
+  global_data(new memory_c((unsigned char *)safememdup(_global_data,
+                                                       _global_size),
+                           _global_size, true)),
+  codec_id(_codec_id), recode(_recode) {
 
   if (recode) {
     if ((ti.sub_charset != "") || !is_utf8)
@@ -55,8 +58,9 @@ textsubs_packetizer_c::~textsubs_packetizer_c() {
 void
 textsubs_packetizer_c::set_headers() {
   set_codec_id(codec_id);
-  if (NULL != global_data.get())
-    set_codec_private((unsigned char *)global_data, global_size);
+  if (NULL != global_data->get())
+    set_codec_private((unsigned char *)global_data->get(),
+                      global_data->get_size());
 
   generic_packetizer_c::set_headers();
 
@@ -67,28 +71,14 @@ int
 textsubs_packetizer_c::process(packet_cptr packet) {
   int num_newlines;
   char *subs, *idx1, *idx2;
-  int64_t end;
-
-  end = packet->timecode + packet->duration;
-  // Adjust the start and end values according to the audio adjustment.
-  packet->timecode += initial_displacement;
-  packet->timecode = (int64_t)(ti.async.linear * packet->timecode);
-  end += initial_displacement;
-  end = (int64_t)(ti.async.linear * end);
-
-  if (end < 0)
-    return FILE_STATUS_MOREDATA;
-  else if (packet->timecode < 0)
-    packet->timecode = 0;
 
   if (packet->duration < 0) {
-    mxwarn("textsubs_packetizer: Ignoring an entry which starts after it ends."
-           "\n");
+    mxwarn("textsubs_packetizer: Ignoring an entry which starts after it ends.\n");
     return FILE_STATUS_MOREDATA;
   }
 
   // Count the number of lines.
-  idx1 = (char *)packet->memory->data;
+  idx1 = (char *)packet->data->get();
   subs = NULL;
   num_newlines = 0;
   while (*idx1 != 0) {
@@ -96,11 +86,11 @@ textsubs_packetizer_c::process(packet_cptr packet) {
       num_newlines++;
     idx1++;
   }
-  subs = (char *)safemalloc(strlen((char *)packet->memory->data) +
+  subs = (char *)safemalloc(strlen((char *)packet->data->get()) +
                             num_newlines * 2 + 1);
 
   // Unify the new lines into DOS style newlines.
-  idx1 = (char *)packet->memory->data;
+  idx1 = (char *)packet->data->get();
   idx2 = subs;
   while (*idx1 != 0) {
     if (*idx1 == '\n') {
@@ -128,13 +118,13 @@ textsubs_packetizer_c::process(packet_cptr packet) {
 
     utf8_subs = to_utf8(cc_utf8, subs);
     safefree(subs);
-    packet->memory =
+    packet->data =
       memory_cptr(new memory_c((unsigned char *)utf8_subs.c_str(),
                                utf8_subs.length(), false));
     add_packet(packet);
 
   } else {
-    packet->memory =
+    packet->data =
       memory_cptr(new memory_c((unsigned char *)subs, strlen(subs), true));
     add_packet(packet);
   }
@@ -142,12 +132,6 @@ textsubs_packetizer_c::process(packet_cptr packet) {
   return FILE_STATUS_MOREDATA;
 }
 
-void
-textsubs_packetizer_c::dump_debug_info() {
-  mxdebug("textsubs_packetizer_c: queue: %u\n",
-          (unsigned int)packet_queue.size());
-}
-
 connection_result_e
 textsubs_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                       string &error_message) {
@@ -156,5 +140,15 @@ textsubs_packetizer_c::can_connect_to(generic_packetizer_c *src,
   psrc = dynamic_cast<textsubs_packetizer_c *>(src);
   if (psrc == NULL)
     return CAN_CONNECT_NO_FORMAT;
+
+  if (((ti.private_data == NULL) && (src->ti.private_data != NULL)) ||
+      ((ti.private_data != NULL) && (src->ti.private_data == NULL)) ||
+      (ti.private_size != src->ti.private_size)) {
+    error_message = mxsprintf("The codec's private data does not match "
+                              "(lengths: %d and %d).", ti.private_size,
+                              src->ti.private_size);
+    return CAN_CONNECT_MAYBE_CODECPRIVATE;
+  }
+
   return CAN_CONNECT_YES;
 }
