@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_textsubs.h 2932 2005-05-25 21:31:26Z mosu $
+   $Id: p_textsubs.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the simple text subtitle packetizer
 
@@ -25,8 +25,7 @@
 class textsubs_packetizer_c: public generic_packetizer_c {
 private:
   int packetno, cc_utf8;
-  autofree_ptr<unsigned char> global_data;
-  int global_size;
+  memory_cptr global_data;
   string codec_id;
   bool recode;
 
@@ -40,8 +39,6 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual void dump_debug_info();
-
   virtual const char *get_format_name() {
     return "text subtitle";
   }
