@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_video.cpp 3754 2008-02-25 17:13:13Z mosu $
+   $Id: p_video.cpp 3838 2008-08-21 15:04:24Z mosu $
 
    video output module
 
@@ -126,13 +126,6 @@ video_packetizer_c::process(packet_cptr packet) {
   return FILE_STATUS_MOREDATA;
 }
 
-void
-video_packetizer_c::dump_debug_info() {
-  mxdebug("video_packetizer_c: queue: %u; frames_output: %d; "
-          "ref_timecode: " LLD "\n", (unsigned int)packet_queue.size(),
-          frames_output, ref_timecode);
-}
-
 connection_result_e
 video_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                    string &error_message) {
