@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_vobsub.h 2932 2005-05-25 21:31:26Z mosu $
+   $Id: p_vobsub.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the VobSub output module
 
@@ -25,8 +25,7 @@
 
 class vobsub_packetizer_c: public generic_packetizer_c {
 private:
-  autofree_ptr<unsigned char> idx_data;
-  int idx_data_size;
+  memory_cptr idx_data;
 
 public:
   vobsub_packetizer_c(generic_reader_c *_reader,
@@ -38,8 +37,6 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual void dump_debug_info();
-
   virtual const char *get_format_name() {
     return "VobSub";
   }
