@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_vorbis.h 2932 2005-05-25 21:31:26Z mosu $
+   $Id: p_vorbis.h 3838 2008-08-21 15:04:24Z mosu $
 
    class definition for the Vorbis packetizer
 
@@ -30,9 +30,9 @@
 class vorbis_packetizer_c: public generic_packetizer_c {
 private:
   int64_t last_bs, samples, last_samples_sum, last_timecode, timecode_offset;
+  vector<memory_cptr> headers;
   vorbis_info vi;
   vorbis_comment vc;
-  ogg_packet headers[3];
 
 public:
   vorbis_packetizer_c(generic_reader_c *_reader,
@@ -45,8 +45,6 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual void dump_debug_info();
-
   virtual const char *get_format_name() {
     return "Vorbis";
   }
