@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_wavpack.cpp 3024 2005-08-17 11:46:09Z mosu $
+   $Id: p_wavpack.cpp 3838 2008-08-21 15:04:24Z mosu $
 
    WAVPACK output module
 
@@ -56,30 +56,21 @@ wavpack_packetizer_c::set_headers() {
 
 int
 wavpack_packetizer_c::process(packet_cptr packet) {
-  debug_enter("wavpack_packetizer_c::process");
-  int64_t samples = get_uint32_le(packet->memory->data);
+  int64_t samples = get_uint32_le(packet->data->get());
 
   if (-1 == packet->duration)
     packet->duration = irnd(samples * 1000000000 / sample_rate);
   else
-    mxverb(2, "wavpack_packetizer: incomplete block with duration %lld\n",
+    mxverb(2, "wavpack_packetizer: incomplete block with duration " LLD "\n",
            packet->duration);
   if (-1 == packet->timecode)
     packet->timecode = irnd((double)samples_output * 1000000000 / sample_rate);
   samples_output += samples;
   add_packet(packet);
 
-  debug_leave("wavpack_packetizer_c::process");
-
   return FILE_STATUS_MOREDATA;
 }
 
-void
-wavpack_packetizer_c::dump_debug_info() {
-  mxdebug("wavpack_packetizer_c: queue: %u\n",
-          (unsigned int)packet_queue.size());
-}
-
 connection_result_e
 wavpack_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                      string &error_message) {
